# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waWeb/WAWebProtobufsWeb.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waWeb/WAWebProtobufsWeb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waE2E import WAWebProtobufsE2E_pb2 as waE2E_dot_WAWebProtobufsE2E__pb2
from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dwaWeb/WAWebProtobufsWeb.proto\x12\x11WAWebProtobufsWeb\x1a\x1dwaE2E/WAWebProtobufsE2E.proto\x1a\x17waCommon/WACommon.proto\"\x9fN\n\x0eWebMessageInfo\x12!\n\x03key\x18\x01 \x02(\x0b\x32\x14.WACommon.MessageKey\x12+\n\x07message\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\x18\n\x10messageTimestamp\x18\x03 \x01(\x04\x12\x38\n\x06status\x18\x04 \x01(\x0e\x32(.WAWebProtobufsWeb.WebMessageInfo.Status\x12\x13\n\x0bparticipant\x18\x05 \x01(\t\x12\x1b\n\x13messageC2STimestamp\x18\x06 \x01(\x04\x12\x0e\n\x06ignore\x18\x10 \x01(\x08\x12\x0f\n\x07starred\x18\x11 \x01(\x08\x12\x11\n\tbroadcast\x18\x12 \x01(\x08\x12\x10\n\x08pushName\x18\x13 \x01(\t\x12\x1d\n\x15mediaCiphertextSHA256\x18\x14 \x01(\x0c\x12\x11\n\tmulticast\x18\x15 \x01(\x08\x12\x0f\n\x07urlText\x18\x16 \x01(\x08\x12\x11\n\turlNumber\x18\x17 \x01(\x08\x12\x43\n\x0fmessageStubType\x18\x18 \x01(\x0e\x32*.WAWebProtobufsWeb.WebMessageInfo.StubType\x12\x12\n\nclearMedia\x18\x19 \x01(\x08\x12\x1d\n\x15messageStubParameters\x18\x1a \x03(\t\x12\x10\n\x08\x64uration\x18\x1b \x01(\r\x12\x0e\n\x06labels\x18\x1c \x03(\t\x12\x33\n\x0bpaymentInfo\x18\x1d \x01(\x0b\x32\x1e.WAWebProtobufsWeb.PaymentInfo\x12\x41\n\x11\x66inalLiveLocation\x18\x1e \x01(\x0b\x32&.WAWebProtobufsE2E.LiveLocationMessage\x12\x39\n\x11quotedPaymentInfo\x18\x1f \x01(\x0b\x32\x1e.WAWebProtobufsWeb.PaymentInfo\x12\x1f\n\x17\x65phemeralStartTimestamp\x18  \x01(\x04\x12\x19\n\x11\x65phemeralDuration\x18! \x01(\r\x12\x18\n\x10\x65phemeralOffToOn\x18\" \x01(\x08\x12\x1a\n\x12\x65phemeralOutOfSync\x18# \x01(\x08\x12L\n\x10\x62izPrivacyStatus\x18$ \x01(\x0e\x32\x32.WAWebProtobufsWeb.WebMessageInfo.BizPrivacyStatus\x12\x17\n\x0fverifiedBizName\x18% \x01(\t\x12/\n\tmediaData\x18& \x01(\x0b\x32\x1c.WAWebProtobufsWeb.MediaData\x12\x33\n\x0bphotoChange\x18\' \x01(\x0b\x32\x1e.WAWebProtobufsWeb.PhotoChange\x12\x33\n\x0buserReceipt\x18( \x03(\x0b\x32\x1e.WAWebProtobufsWeb.UserReceipt\x12.\n\treactions\x18) \x03(\x0b\x32\x1b.WAWebProtobufsWeb.Reaction\x12\x37\n\x11quotedStickerData\x18* \x01(\x0b\x32\x1c.WAWebProtobufsWeb.MediaData\x12\x17\n\x0f\x66utureproofData\x18+ \x01(\x0c\x12/\n\tstatusPsa\x18, \x01(\x0b\x32\x1c.WAWebProtobufsWeb.StatusPSA\x12\x32\n\x0bpollUpdates\x18- \x03(\x0b\x32\x1d.WAWebProtobufsWeb.PollUpdate\x12I\n\x16pollAdditionalMetadata\x18. \x01(\x0b\x32).WAWebProtobufsWeb.PollAdditionalMetadata\x12\x0f\n\x07\x61gentID\x18/ \x01(\t\x12\x1b\n\x13statusAlreadyViewed\x18\x30 \x01(\x08\x12\x15\n\rmessageSecret\x18\x31 \x01(\x0c\x12\x31\n\nkeepInChat\x18\x32 \x01(\x0b\x32\x1d.WAWebProtobufsWeb.KeepInChat\x12\'\n\x1foriginalSelfAuthorUserJIDString\x18\x33 \x01(\t\x12\x1e\n\x16revokeMessageTimestamp\x18\x34 \x01(\x04\x12/\n\tpinInChat\x18\x36 \x01(\x0b\x32\x1c.WAWebProtobufsWeb.PinInChat\x12\x41\n\x12premiumMessageInfo\x18\x37 \x01(\x0b\x32%.WAWebProtobufsWeb.PremiumMessageInfo\x12\x19\n\x11is1PBizBotMessage\x18\x38 \x01(\x08\x12\x1d\n\x15isGroupHistoryMessage\x18\x39 \x01(\x08\x12\x1c\n\x14\x62otMessageInvokerJID\x18: \x01(\t\x12;\n\x0f\x63ommentMetadata\x18; \x01(\x0b\x32\".WAWebProtobufsWeb.CommentMetadata\x12\x38\n\x0e\x65ventResponses\x18= \x03(\x0b\x32 .WAWebProtobufsWeb.EventResponse\x12\x41\n\x12reportingTokenInfo\x18> \x01(\x0b\x32%.WAWebProtobufsWeb.ReportingTokenInfo\x12\x1a\n\x12newsletterServerID\x18? \x01(\x04\x12K\n\x17\x65ventAdditionalMetadata\x18@ \x01(\x0b\x32*.WAWebProtobufsWeb.EventAdditionalMetadata\x12\x1b\n\x13isMentionedInStatus\x18\x41 \x01(\x08\x12\x16\n\x0estatusMentions\x18\x42 \x03(\t\x12-\n\x0ftargetMessageID\x18\x43 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x36\n\rmessageAddOns\x18\x44 \x03(\x0b\x32\x1f.WAWebProtobufsWeb.MessageAddOn\x12I\n\x18statusMentionMessageInfo\x18\x45 \x01(\x0b\x32\'.WAWebProtobufsWeb.StatusMentionMessage\x12\x1a\n\x12isSupportAiMessage\x18\x46 \x01(\x08\x12\x1c\n\x14statusMentionSources\x18G \x03(\t\x12\x37\n\x12supportAiCitations\x18H \x03(\x0b\x32\x1b.WAWebProtobufsWeb.Citation\x12\x13\n\x0b\x62otTargetID\x18I \x01(\t\"=\n\x10\x42izPrivacyStatus\x12\x08\n\x04\x45\x32\x45\x45\x10\x00\x12\x06\n\x02\x46\x42\x10\x02\x12\x07\n\x03\x42SP\x10\x01\x12\x0e\n\nBSP_AND_FB\x10\x03\"\xef\x39\n\x08StubType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06REVOKE\x10\x01\x12\x0e\n\nCIPHERTEXT\x10\x02\x12\x0f\n\x0b\x46UTUREPROOF\x10\x03\x12\x1b\n\x17NON_VERIFIED_TRANSITION\x10\x04\x12\x19\n\x15UNVERIFIED_TRANSITION\x10\x05\x12\x17\n\x13VERIFIED_TRANSITION\x10\x06\x12\x18\n\x14VERIFIED_LOW_UNKNOWN\x10\x07\x12\x11\n\rVERIFIED_HIGH\x10\x08\x12\x1c\n\x18VERIFIED_INITIAL_UNKNOWN\x10\t\x12\x18\n\x14VERIFIED_INITIAL_LOW\x10\n\x12\x19\n\x15VERIFIED_INITIAL_HIGH\x10\x0b\x12#\n\x1fVERIFIED_TRANSITION_ANY_TO_NONE\x10\x0c\x12#\n\x1fVERIFIED_TRANSITION_ANY_TO_HIGH\x10\r\x12#\n\x1fVERIFIED_TRANSITION_HIGH_TO_LOW\x10\x0e\x12\'\n#VERIFIED_TRANSITION_HIGH_TO_UNKNOWN\x10\x0f\x12&\n\"VERIFIED_TRANSITION_UNKNOWN_TO_LOW\x10\x10\x12&\n\"VERIFIED_TRANSITION_LOW_TO_UNKNOWN\x10\x11\x12#\n\x1fVERIFIED_TRANSITION_NONE_TO_LOW\x10\x12\x12\'\n#VERIFIED_TRANSITION_NONE_TO_UNKNOWN\x10\x13\x12\x10\n\x0cGROUP_CREATE\x10\x14\x12\x18\n\x14GROUP_CHANGE_SUBJECT\x10\x15\x12\x15\n\x11GROUP_CHANGE_ICON\x10\x16\x12\x1c\n\x18GROUP_CHANGE_INVITE_LINK\x10\x17\x12\x1c\n\x18GROUP_CHANGE_DESCRIPTION\x10\x18\x12\x19\n\x15GROUP_CHANGE_RESTRICT\x10\x19\x12\x19\n\x15GROUP_CHANGE_ANNOUNCE\x10\x1a\x12\x19\n\x15GROUP_PARTICIPANT_ADD\x10\x1b\x12\x1c\n\x18GROUP_PARTICIPANT_REMOVE\x10\x1c\x12\x1d\n\x19GROUP_PARTICIPANT_PROMOTE\x10\x1d\x12\x1c\n\x18GROUP_PARTICIPANT_DEMOTE\x10\x1e\x12\x1c\n\x18GROUP_PARTICIPANT_INVITE\x10\x1f\x12\x1b\n\x17GROUP_PARTICIPANT_LEAVE\x10 \x12#\n\x1fGROUP_PARTICIPANT_CHANGE_NUMBER\x10!\x12\x14\n\x10\x42ROADCAST_CREATE\x10\"\x12\x11\n\rBROADCAST_ADD\x10#\x12\x14\n\x10\x42ROADCAST_REMOVE\x10$\x12\x18\n\x14GENERIC_NOTIFICATION\x10%\x12\x18\n\x14\x45\x32\x45_IDENTITY_CHANGED\x10&\x12\x11\n\rE2E_ENCRYPTED\x10\'\x12\x15\n\x11\x43\x41LL_MISSED_VOICE\x10(\x12\x15\n\x11\x43\x41LL_MISSED_VIDEO\x10)\x12\x1c\n\x18INDIVIDUAL_CHANGE_NUMBER\x10*\x12\x10\n\x0cGROUP_DELETE\x10+\x12&\n\"GROUP_ANNOUNCE_MODE_MESSAGE_BOUNCE\x10,\x12\x1b\n\x17\x43\x41LL_MISSED_GROUP_VOICE\x10-\x12\x1b\n\x17\x43\x41LL_MISSED_GROUP_VIDEO\x10.\x12\x16\n\x12PAYMENT_CIPHERTEXT\x10/\x12\x17\n\x13PAYMENT_FUTUREPROOF\x10\x30\x12,\n(PAYMENT_TRANSACTION_STATUS_UPDATE_FAILED\x10\x31\x12.\n*PAYMENT_TRANSACTION_STATUS_UPDATE_REFUNDED\x10\x32\x12\x33\n/PAYMENT_TRANSACTION_STATUS_UPDATE_REFUND_FAILED\x10\x33\x12\x35\n1PAYMENT_TRANSACTION_STATUS_RECEIVER_PENDING_SETUP\x10\x34\x12<\n8PAYMENT_TRANSACTION_STATUS_RECEIVER_SUCCESS_AFTER_HICCUP\x10\x35\x12)\n%PAYMENT_ACTION_ACCOUNT_SETUP_REMINDER\x10\x36\x12(\n$PAYMENT_ACTION_SEND_PAYMENT_REMINDER\x10\x37\x12*\n&PAYMENT_ACTION_SEND_PAYMENT_INVITATION\x10\x38\x12#\n\x1fPAYMENT_ACTION_REQUEST_DECLINED\x10\x39\x12\"\n\x1ePAYMENT_ACTION_REQUEST_EXPIRED\x10:\x12$\n PAYMENT_ACTION_REQUEST_CANCELLED\x10;\x12)\n%BIZ_VERIFIED_TRANSITION_TOP_TO_BOTTOM\x10<\x12)\n%BIZ_VERIFIED_TRANSITION_BOTTOM_TO_TOP\x10=\x12\x11\n\rBIZ_INTRO_TOP\x10>\x12\x14\n\x10\x42IZ_INTRO_BOTTOM\x10?\x12\x13\n\x0f\x42IZ_NAME_CHANGE\x10@\x12\x1c\n\x18\x42IZ_MOVE_TO_CONSUMER_APP\x10\x41\x12\x1e\n\x1a\x42IZ_TWO_TIER_MIGRATION_TOP\x10\x42\x12!\n\x1d\x42IZ_TWO_TIER_MIGRATION_BOTTOM\x10\x43\x12\r\n\tOVERSIZED\x10\x44\x12(\n$GROUP_CHANGE_NO_FREQUENTLY_FORWARDED\x10\x45\x12\x1c\n\x18GROUP_V4_ADD_INVITE_SENT\x10\x46\x12&\n\"GROUP_PARTICIPANT_ADD_REQUEST_JOIN\x10G\x12\x1c\n\x18\x43HANGE_EPHEMERAL_SETTING\x10H\x12\x16\n\x12\x45\x32\x45_DEVICE_CHANGED\x10I\x12\x0f\n\x0bVIEWED_ONCE\x10J\x12\x15\n\x11\x45\x32\x45_ENCRYPTED_NOW\x10K\x12\"\n\x1e\x42LUE_MSG_BSP_FB_TO_BSP_PREMISE\x10L\x12\x1e\n\x1a\x42LUE_MSG_BSP_FB_TO_SELF_FB\x10M\x12#\n\x1f\x42LUE_MSG_BSP_FB_TO_SELF_PREMISE\x10N\x12\x1e\n\x1a\x42LUE_MSG_BSP_FB_UNVERIFIED\x10O\x12\x37\n3BLUE_MSG_BSP_FB_UNVERIFIED_TO_SELF_PREMISE_VERIFIED\x10P\x12\x1c\n\x18\x42LUE_MSG_BSP_FB_VERIFIED\x10Q\x12\x37\n3BLUE_MSG_BSP_FB_VERIFIED_TO_SELF_PREMISE_UNVERIFIED\x10R\x12(\n$BLUE_MSG_BSP_PREMISE_TO_SELF_PREMISE\x10S\x12#\n\x1f\x42LUE_MSG_BSP_PREMISE_UNVERIFIED\x10T\x12<\n8BLUE_MSG_BSP_PREMISE_UNVERIFIED_TO_SELF_PREMISE_VERIFIED\x10U\x12!\n\x1d\x42LUE_MSG_BSP_PREMISE_VERIFIED\x10V\x12<\n8BLUE_MSG_BSP_PREMISE_VERIFIED_TO_SELF_PREMISE_UNVERIFIED\x10W\x12*\n&BLUE_MSG_CONSUMER_TO_BSP_FB_UNVERIFIED\x10X\x12/\n+BLUE_MSG_CONSUMER_TO_BSP_PREMISE_UNVERIFIED\x10Y\x12+\n\'BLUE_MSG_CONSUMER_TO_SELF_FB_UNVERIFIED\x10Z\x12\x30\n,BLUE_MSG_CONSUMER_TO_SELF_PREMISE_UNVERIFIED\x10[\x12#\n\x1f\x42LUE_MSG_SELF_FB_TO_BSP_PREMISE\x10\\\x12$\n BLUE_MSG_SELF_FB_TO_SELF_PREMISE\x10]\x12\x1f\n\x1b\x42LUE_MSG_SELF_FB_UNVERIFIED\x10^\x12\x38\n4BLUE_MSG_SELF_FB_UNVERIFIED_TO_SELF_PREMISE_VERIFIED\x10_\x12\x1d\n\x19\x42LUE_MSG_SELF_FB_VERIFIED\x10`\x12\x38\n4BLUE_MSG_SELF_FB_VERIFIED_TO_SELF_PREMISE_UNVERIFIED\x10\x61\x12(\n$BLUE_MSG_SELF_PREMISE_TO_BSP_PREMISE\x10\x62\x12$\n BLUE_MSG_SELF_PREMISE_UNVERIFIED\x10\x63\x12\"\n\x1e\x42LUE_MSG_SELF_PREMISE_VERIFIED\x10\x64\x12\x16\n\x12\x42LUE_MSG_TO_BSP_FB\x10\x65\x12\x18\n\x14\x42LUE_MSG_TO_CONSUMER\x10\x66\x12\x17\n\x13\x42LUE_MSG_TO_SELF_FB\x10g\x12*\n&BLUE_MSG_UNVERIFIED_TO_BSP_FB_VERIFIED\x10h\x12/\n+BLUE_MSG_UNVERIFIED_TO_BSP_PREMISE_VERIFIED\x10i\x12+\n\'BLUE_MSG_UNVERIFIED_TO_SELF_FB_VERIFIED\x10j\x12#\n\x1f\x42LUE_MSG_UNVERIFIED_TO_VERIFIED\x10k\x12*\n&BLUE_MSG_VERIFIED_TO_BSP_FB_UNVERIFIED\x10l\x12/\n+BLUE_MSG_VERIFIED_TO_BSP_PREMISE_UNVERIFIED\x10m\x12+\n\'BLUE_MSG_VERIFIED_TO_SELF_FB_UNVERIFIED\x10n\x12#\n\x1f\x42LUE_MSG_VERIFIED_TO_UNVERIFIED\x10o\x12\x36\n2BLUE_MSG_BSP_FB_UNVERIFIED_TO_BSP_PREMISE_VERIFIED\x10p\x12\x32\n.BLUE_MSG_BSP_FB_UNVERIFIED_TO_SELF_FB_VERIFIED\x10q\x12\x36\n2BLUE_MSG_BSP_FB_VERIFIED_TO_BSP_PREMISE_UNVERIFIED\x10r\x12\x32\n.BLUE_MSG_BSP_FB_VERIFIED_TO_SELF_FB_UNVERIFIED\x10s\x12\x37\n3BLUE_MSG_SELF_FB_UNVERIFIED_TO_BSP_PREMISE_VERIFIED\x10t\x12\x37\n3BLUE_MSG_SELF_FB_VERIFIED_TO_BSP_PREMISE_UNVERIFIED\x10u\x12\x1c\n\x18\x45\x32\x45_IDENTITY_UNAVAILABLE\x10v\x12\x12\n\x0eGROUP_CREATING\x10w\x12\x17\n\x13GROUP_CREATE_FAILED\x10x\x12\x11\n\rGROUP_BOUNCED\x10y\x12\x11\n\rBLOCK_CONTACT\x10z\x12!\n\x1d\x45PHEMERAL_SETTING_NOT_APPLIED\x10{\x12\x0f\n\x0bSYNC_FAILED\x10|\x12\x0b\n\x07SYNCING\x10}\x12\x1c\n\x18\x42IZ_PRIVACY_MODE_INIT_FB\x10~\x12\x1d\n\x19\x42IZ_PRIVACY_MODE_INIT_BSP\x10\x7f\x12\x1b\n\x16\x42IZ_PRIVACY_MODE_TO_FB\x10\x80\x01\x12\x1c\n\x17\x42IZ_PRIVACY_MODE_TO_BSP\x10\x81\x01\x12\x16\n\x11\x44ISAPPEARING_MODE\x10\x82\x01\x12\x1c\n\x17\x45\x32\x45_DEVICE_FETCH_FAILED\x10\x83\x01\x12\x11\n\x0c\x41\x44MIN_REVOKE\x10\x84\x01\x12$\n\x1fGROUP_INVITE_LINK_GROWTH_LOCKED\x10\x85\x01\x12 \n\x1b\x43OMMUNITY_LINK_PARENT_GROUP\x10\x86\x01\x12!\n\x1c\x43OMMUNITY_LINK_SIBLING_GROUP\x10\x87\x01\x12\x1d\n\x18\x43OMMUNITY_LINK_SUB_GROUP\x10\x88\x01\x12\"\n\x1d\x43OMMUNITY_UNLINK_PARENT_GROUP\x10\x89\x01\x12#\n\x1e\x43OMMUNITY_UNLINK_SIBLING_GROUP\x10\x8a\x01\x12\x1f\n\x1a\x43OMMUNITY_UNLINK_SUB_GROUP\x10\x8b\x01\x12\x1d\n\x18GROUP_PARTICIPANT_ACCEPT\x10\x8c\x01\x12(\n#GROUP_PARTICIPANT_LINKED_GROUP_JOIN\x10\x8d\x01\x12\x15\n\x10\x43OMMUNITY_CREATE\x10\x8e\x01\x12\x1b\n\x16\x45PHEMERAL_KEEP_IN_CHAT\x10\x8f\x01\x12+\n&GROUP_MEMBERSHIP_JOIN_APPROVAL_REQUEST\x10\x90\x01\x12(\n#GROUP_MEMBERSHIP_JOIN_APPROVAL_MODE\x10\x91\x01\x12\"\n\x1dINTEGRITY_UNLINK_PARENT_GROUP\x10\x92\x01\x12\"\n\x1d\x43OMMUNITY_PARTICIPANT_PROMOTE\x10\x93\x01\x12!\n\x1c\x43OMMUNITY_PARTICIPANT_DEMOTE\x10\x94\x01\x12#\n\x1e\x43OMMUNITY_PARENT_GROUP_DELETED\x10\x95\x01\x12\x34\n/COMMUNITY_LINK_PARENT_GROUP_MEMBERSHIP_APPROVAL\x10\x96\x01\x12\x34\n/GROUP_PARTICIPANT_JOINED_GROUP_AND_PARENT_GROUP\x10\x97\x01\x12\x1a\n\x15MASKED_THREAD_CREATED\x10\x98\x01\x12\x1b\n\x16MASKED_THREAD_UNMASKED\x10\x99\x01\x12\x18\n\x13\x42IZ_CHAT_ASSIGNMENT\x10\x9a\x01\x12\r\n\x08\x43HAT_PSA\x10\x9b\x01\x12\x1f\n\x1a\x43HAT_POLL_CREATION_MESSAGE\x10\x9c\x01\x12\x1e\n\x19\x43\x41G_MASKED_THREAD_CREATED\x10\x9d\x01\x12+\n&COMMUNITY_PARENT_GROUP_SUBJECT_CHANGED\x10\x9e\x01\x12\x18\n\x13\x43\x41G_INVITE_AUTO_ADD\x10\x9f\x01\x12!\n\x1c\x42IZ_CHAT_ASSIGNMENT_UNASSIGN\x10\xa0\x01\x12\x1b\n\x16\x43\x41G_INVITE_AUTO_JOINED\x10\xa1\x01\x12!\n\x1cSCHEDULED_CALL_START_MESSAGE\x10\xa2\x01\x12\x1a\n\x15\x43OMMUNITY_INVITE_RICH\x10\xa3\x01\x12#\n\x1e\x43OMMUNITY_INVITE_AUTO_ADD_RICH\x10\xa4\x01\x12\x1a\n\x15SUB_GROUP_INVITE_RICH\x10\xa5\x01\x12#\n\x1eSUB_GROUP_PARTICIPANT_ADD_RICH\x10\xa6\x01\x12%\n COMMUNITY_LINK_PARENT_GROUP_RICH\x10\xa7\x01\x12#\n\x1e\x43OMMUNITY_PARTICIPANT_ADD_RICH\x10\xa8\x01\x12\"\n\x1dSILENCED_UNKNOWN_CALLER_AUDIO\x10\xa9\x01\x12\"\n\x1dSILENCED_UNKNOWN_CALLER_VIDEO\x10\xaa\x01\x12\x1a\n\x15GROUP_MEMBER_ADD_MODE\x10\xab\x01\x12\x39\n4GROUP_MEMBERSHIP_JOIN_APPROVAL_REQUEST_NON_ADMIN_ADD\x10\xac\x01\x12!\n\x1c\x43OMMUNITY_CHANGE_DESCRIPTION\x10\xad\x01\x12\x12\n\rSENDER_INVITE\x10\xae\x01\x12\x14\n\x0fRECEIVER_INVITE\x10\xaf\x01\x12(\n#COMMUNITY_ALLOW_MEMBER_ADDED_GROUPS\x10\xb0\x01\x12\x1b\n\x16PINNED_MESSAGE_IN_CHAT\x10\xb1\x01\x12!\n\x1cPAYMENT_INVITE_SETUP_INVITER\x10\xb2\x01\x12.\n)PAYMENT_INVITE_SETUP_INVITEE_RECEIVE_ONLY\x10\xb3\x01\x12\x32\n-PAYMENT_INVITE_SETUP_INVITEE_SEND_AND_RECEIVE\x10\xb4\x01\x12\x1c\n\x17LINKED_GROUP_CALL_START\x10\xb5\x01\x12#\n\x1eREPORT_TO_ADMIN_ENABLED_STATUS\x10\xb6\x01\x12\x1a\n\x15\x45MPTY_SUBGROUP_CREATE\x10\xb7\x01\x12\x1a\n\x15SCHEDULED_CALL_CANCEL\x10\xb8\x01\x12+\n&SUBGROUP_ADMIN_TRIGGERED_AUTO_ADD_RICH\x10\xb9\x01\x12(\n#GROUP_CHANGE_RECENT_HISTORY_SHARING\x10\xba\x01\x12$\n\x1fPAID_MESSAGE_SERVER_CAMPAIGN_ID\x10\xbb\x01\x12\x18\n\x13GENERAL_CHAT_CREATE\x10\xbc\x01\x12\x15\n\x10GENERAL_CHAT_ADD\x10\xbd\x01\x12#\n\x1eGENERAL_CHAT_AUTO_ADD_DISABLED\x10\xbe\x01\x12 \n\x1bSUGGESTED_SUBGROUP_ANNOUNCE\x10\xbf\x01\x12!\n\x1c\x42IZ_BOT_1P_MESSAGING_ENABLED\x10\xc0\x01\x12\x14\n\x0f\x43HANGE_USERNAME\x10\xc1\x01\x12\x1f\n\x1a\x42IZ_COEX_PRIVACY_INIT_SELF\x10\xc2\x01\x12%\n BIZ_COEX_PRIVACY_TRANSITION_SELF\x10\xc3\x01\x12\x19\n\x14SUPPORT_AI_EDUCATION\x10\xc4\x01\x12!\n\x1c\x42IZ_BOT_3P_MESSAGING_ENABLED\x10\xc5\x01\x12\x1b\n\x16REMINDER_SETUP_MESSAGE\x10\xc6\x01\x12\x1a\n\x15REMINDER_SENT_MESSAGE\x10\xc7\x01\x12\x1c\n\x17REMINDER_CANCEL_MESSAGE\x10\xc8\x01\x12\x1a\n\x15\x42IZ_COEX_PRIVACY_INIT\x10\xc9\x01\x12 \n\x1b\x42IZ_COEX_PRIVACY_TRANSITION\x10\xca\x01\x12\x16\n\x11GROUP_DEACTIVATED\x10\xcb\x01\x12\'\n\"COMMUNITY_DEACTIVATE_SIBLING_GROUP\x10\xcc\x01\x12\x12\n\rEVENT_UPDATED\x10\xcd\x01\x12\x13\n\x0e\x45VENT_CANCELED\x10\xce\x01\x12\x1c\n\x17\x43OMMUNITY_OWNER_UPDATED\x10\xcf\x01\x12*\n%COMMUNITY_SUB_GROUP_VISIBILITY_HIDDEN\x10\xd0\x01\x12$\n\x1f\x43\x41PI_GROUP_NE2EE_SYSTEM_MESSAGE\x10\xd1\x01\x12\x13\n\x0eSTATUS_MENTION\x10\xd2\x01\x12!\n\x1cUSER_CONTROLS_SYSTEM_MESSAGE\x10\xd3\x01\x12\x1b\n\x16SUPPORT_SYSTEM_MESSAGE\x10\xd4\x01\x12\x0f\n\nCHANGE_LID\x10\xd5\x01\x12\x31\n,BIZ_CUSTOMER_3PD_DATA_SHARING_OPT_IN_MESSAGE\x10\xd6\x01\x12\x32\n-BIZ_CUSTOMER_3PD_DATA_SHARING_OPT_OUT_MESSAGE\x10\xd7\x01\x12\x19\n\x14\x43HANGE_LIMIT_SHARING\x10\xd8\x01\x12\x1b\n\x16GROUP_MEMBER_LINK_MODE\x10\xd9\x01\"X\n\x06Status\x12\t\n\x05\x45RROR\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nSERVER_ACK\x10\x02\x12\x10\n\x0c\x44\x45LIVERY_ACK\x10\x03\x12\x08\n\x04READ\x10\x04\x12\n\n\x06PLAYED\x10\x05\"\x94\x0b\n\x0bPaymentInfo\x12\x43\n\x12\x63urrencyDeprecated\x18\x01 \x01(\x0e\x32\'.WAWebProtobufsWeb.PaymentInfo.Currency\x12\x12\n\namount1000\x18\x02 \x01(\x04\x12\x13\n\x0breceiverJID\x18\x03 \x01(\t\x12\x35\n\x06status\x18\x04 \x01(\x0e\x32%.WAWebProtobufsWeb.PaymentInfo.Status\x12\x1c\n\x14transactionTimestamp\x18\x05 \x01(\x04\x12/\n\x11requestMessageKey\x18\x06 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x17\n\x0f\x65xpiryTimestamp\x18\x07 \x01(\x04\x12\x15\n\rfutureproofed\x18\x08 \x01(\x08\x12\x10\n\x08\x63urrency\x18\t \x01(\t\x12;\n\ttxnStatus\x18\n \x01(\x0e\x32(.WAWebProtobufsWeb.PaymentInfo.TxnStatus\x12\x19\n\x11useNoviFiatFormat\x18\x0b \x01(\x08\x12/\n\rprimaryAmount\x18\x0c \x01(\x0b\x32\x18.WAWebProtobufsE2E.Money\x12\x30\n\x0e\x65xchangeAmount\x18\r \x01(\x0b\x32\x18.WAWebProtobufsE2E.Money\"\x99\x05\n\tTxnStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rPENDING_SETUP\x10\x01\x12\x1a\n\x16PENDING_RECEIVER_SETUP\x10\x02\x12\x08\n\x04INIT\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\r\n\tCOMPLETED\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\x12\x0f\n\x0b\x46\x41ILED_RISK\x10\x07\x12\x15\n\x11\x46\x41ILED_PROCESSING\x10\x08\x12\x1e\n\x1a\x46\x41ILED_RECEIVER_PROCESSING\x10\t\x12\r\n\tFAILED_DA\x10\n\x12\x13\n\x0f\x46\x41ILED_DA_FINAL\x10\x0b\x12\x10\n\x0cREFUNDED_TXN\x10\x0c\x12\x11\n\rREFUND_FAILED\x10\r\x12\x1c\n\x18REFUND_FAILED_PROCESSING\x10\x0e\x12\x14\n\x10REFUND_FAILED_DA\x10\x0f\x12\x0f\n\x0b\x45XPIRED_TXN\x10\x10\x12\x11\n\rAUTH_CANCELED\x10\x11\x12!\n\x1d\x41UTH_CANCEL_FAILED_PROCESSING\x10\x12\x12\x16\n\x12\x41UTH_CANCEL_FAILED\x10\x13\x12\x10\n\x0c\x43OLLECT_INIT\x10\x14\x12\x13\n\x0f\x43OLLECT_SUCCESS\x10\x15\x12\x12\n\x0e\x43OLLECT_FAILED\x10\x16\x12\x17\n\x13\x43OLLECT_FAILED_RISK\x10\x17\x12\x14\n\x10\x43OLLECT_REJECTED\x10\x18\x12\x13\n\x0f\x43OLLECT_EXPIRED\x10\x19\x12\x14\n\x10\x43OLLECT_CANCELED\x10\x1a\x12\x16\n\x12\x43OLLECT_CANCELLING\x10\x1b\x12\r\n\tIN_REVIEW\x10\x1c\x12\x14\n\x10REVERSAL_SUCCESS\x10\x1d\x12\x14\n\x10REVERSAL_PENDING\x10\x1e\x12\x12\n\x0eREFUND_PENDING\x10\x1f\"\xcc\x01\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0e\n\nPROCESSING\x10\x01\x12\x08\n\x04SENT\x10\x02\x12\x12\n\x0eNEED_TO_ACCEPT\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\x16\n\x12\x43OULD_NOT_COMPLETE\x10\x05\x12\x0c\n\x08REFUNDED\x10\x06\x12\x0b\n\x07\x45XPIRED\x10\x07\x12\x0c\n\x08REJECTED\x10\x08\x12\r\n\tCANCELLED\x10\t\x12\x15\n\x11WAITING_FOR_PAYER\x10\n\x12\x0b\n\x07WAITING\x10\x0b\")\n\x08\x43urrency\x12\x14\n\x10UNKNOWN_CURRENCY\x10\x00\x12\x07\n\x03INR\x10\x01\"\xf7\x16\n\x0bWebFeatures\x12:\n\rlabelsDisplay\x18\x01 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x43\n\x16voipIndividualOutgoing\x18\x02 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x35\n\x08groupsV3\x18\x03 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12;\n\x0egroupsV3Create\x18\x04 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12;\n\x0e\x63hangeNumberV2\x18\x05 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x43\n\x16queryStatusV3Thumbnail\x18\x06 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12:\n\rliveLocations\x18\x07 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x37\n\nqueryVname\x18\x08 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x43\n\x16voipIndividualIncoming\x18\t \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12>\n\x11quickRepliesQuery\x18\n \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x35\n\x08payments\x18\x0b \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12=\n\x10stickerPackQuery\x18\x0c \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12?\n\x12liveLocationsFinal\x18\r \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x37\n\nlabelsEdit\x18\x0e \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x38\n\x0bmediaUpload\x18\x0f \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12H\n\x1bmediaUploadRichQuickReplies\x18\x12 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x34\n\x07vnameV2\x18\x13 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12=\n\x10videoPlaybackURL\x18\x14 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12:\n\rstatusRanking\x18\x15 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12@\n\x13voipIndividualVideo\x18\x16 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12?\n\x12thirdPartyStickers\x18\x17 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12G\n\x1a\x66requentlyForwardedSetting\x18\x18 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x43\n\x16groupsV4JoinPermission\x18\x19 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12;\n\x0erecentStickers\x18\x1a \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x34\n\x07\x63\x61talog\x18\x1b \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12<\n\x0fstarredStickers\x18\x1c \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12:\n\rvoipGroupCall\x18\x1d \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12<\n\x0ftemplateMessage\x18\x1e \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12I\n\x1ctemplateMessageInteractivity\x18\x1f \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12>\n\x11\x65phemeralMessages\x18  \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12@\n\x13\x65\x32\x45NotificationSync\x18! \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12=\n\x10recentStickersV2\x18\" \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12=\n\x10recentStickersV3\x18$ \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x37\n\nuserNotice\x18% \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x34\n\x07support\x18\' \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12<\n\x0fgroupUiiCleanup\x18( \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12H\n\x1bgroupDogfoodingInternalOnly\x18) \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x39\n\x0csettingsSync\x18* \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x36\n\tarchiveV2\x18+ \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12G\n\x1a\x65phemeralAllowGroupMembers\x18, \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x41\n\x14\x65phemeral24HDuration\x18- \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12;\n\x0emdForceUpgrade\x18. \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12=\n\x10\x64isappearingMode\x18/ \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x45\n\x18\x65xternalMdOptInAvailable\x18\x30 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\x12\x45\n\x18noDeleteMessageTimeLimit\x18\x31 \x01(\x0e\x32#.WAWebProtobufsWeb.WebFeatures.Flag\"K\n\x04\x46lag\x12\x0f\n\x0bNOT_STARTED\x10\x00\x12\x11\n\rFORCE_UPGRADE\x10\x01\x12\x0f\n\x0b\x44\x45VELOPMENT\x10\x02\x12\x0e\n\nPRODUCTION\x10\x03\"\xa0\x02\n\tPinInChat\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.WAWebProtobufsWeb.PinInChat.Type\x12!\n\x03key\x18\x02 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x19\n\x11senderTimestampMS\x18\x03 \x01(\x03\x12\x19\n\x11serverTimestampMS\x18\x04 \x01(\x03\x12K\n\x17messageAddOnContextInfo\x18\x05 \x01(\x0b\x32*.WAWebProtobufsWeb.MessageAddOnContextInfo\"<\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bPIN_FOR_ALL\x10\x01\x12\x11\n\rUNPIN_FOR_ALL\x10\x02\"\x91\x04\n\x0cMessageAddOn\x12J\n\x10messageAddOnType\x18\x01 \x01(\x0e\x32\x30.WAWebProtobufsWeb.MessageAddOn.MessageAddOnType\x12\x30\n\x0cmessageAddOn\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\x19\n\x11senderTimestampMS\x18\x03 \x01(\x03\x12\x19\n\x11serverTimestampMS\x18\x04 \x01(\x03\x12\x38\n\x06status\x18\x05 \x01(\x0e\x32(.WAWebProtobufsWeb.WebMessageInfo.Status\x12\x44\n\x10\x61\x64\x64OnContextInfo\x18\x06 \x01(\x0b\x32*.WAWebProtobufsWeb.MessageAddOnContextInfo\x12-\n\x0fmessageAddOnKey\x18\x07 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x37\n\rlegacyMessage\x18\x08 \x01(\x0b\x32 .WAWebProtobufsWeb.LegacyMessage\"e\n\x10MessageAddOnType\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08REACTION\x10\x01\x12\x12\n\x0e\x45VENT_RESPONSE\x10\x02\x12\x0f\n\x0bPOLL_UPDATE\x10\x03\x12\x0f\n\x0bPIN_IN_CHAT\x10\x04\"U\n\x0f\x43ommentMetadata\x12.\n\x10\x63ommentParentKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x12\n\nreplyCount\x18\x02 \x01(\r\"\x95\x01\n\x14WebNotificationsInfo\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0bunreadChats\x18\x03 \x01(\r\x12\x1a\n\x12notifyMessageCount\x18\x04 \x01(\r\x12\x39\n\x0enotifyMessages\x18\x05 \x03(\x0b\x32!.WAWebProtobufsWeb.WebMessageInfo\"\x98\x01\n\x17NotificationMessageInfo\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12+\n\x07message\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\x18\n\x10messageTimestamp\x18\x03 \x01(\x04\x12\x13\n\x0bparticipant\x18\x04 \x01(\t\"*\n\x12ReportingTokenInfo\x12\x14\n\x0creportingTag\x18\x01 \x01(\x0c\"\x1e\n\tMediaData\x12\x11\n\tlocalPath\x18\x01 \x01(\t\"E\n\x0bPhotoChange\x12\x10\n\x08oldPhoto\x18\x01 \x01(\x0c\x12\x10\n\x08newPhoto\x18\x02 \x01(\x0c\x12\x12\n\nnewPhotoID\x18\x03 \x01(\r\"D\n\tStatusPSA\x12\x12\n\ncampaignID\x18, \x02(\x04\x12#\n\x1b\x63\x61mpaignExpirationTimestamp\x18- \x01(\x04\"\x9e\x01\n\x0bUserReceipt\x12\x0f\n\x07userJID\x18\x01 \x02(\t\x12\x18\n\x10receiptTimestamp\x18\x02 \x01(\x03\x12\x15\n\rreadTimestamp\x18\x03 \x01(\x03\x12\x17\n\x0fplayedTimestamp\x18\x04 \x01(\x03\x12\x18\n\x10pendingDeviceJID\x18\x05 \x03(\t\x12\x1a\n\x12\x64\x65liveredDeviceJID\x18\x06 \x03(\t\"{\n\x08Reaction\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0bgroupingKey\x18\x03 \x01(\t\x12\x19\n\x11senderTimestampMS\x18\x04 \x01(\x03\x12\x0e\n\x06unread\x18\x05 \x01(\x08\"\xb8\x01\n\nPollUpdate\x12\x32\n\x14pollUpdateMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x30\n\x04vote\x18\x02 \x01(\x0b\x32\".WAWebProtobufsE2E.PollVoteMessage\x12\x19\n\x11senderTimestampMS\x18\x03 \x01(\x03\x12\x19\n\x11serverTimestampMS\x18\x04 \x01(\x03\x12\x0e\n\x06unread\x18\x05 \x01(\x08\"1\n\x16PollAdditionalMetadata\x12\x17\n\x0fpollInvalidated\x18\x01 \x01(\x08\"*\n\x17\x45ventAdditionalMetadata\x12\x0f\n\x07isStale\x18\x01 \x01(\x08\"\xc0\x01\n\nKeepInChat\x12-\n\x08keepType\x18\x01 \x01(\x0e\x32\x1b.WAWebProtobufsE2E.KeepType\x12\x17\n\x0fserverTimestamp\x18\x02 \x01(\x03\x12!\n\x03key\x18\x03 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x11\n\tdeviceJID\x18\x04 \x01(\t\x12\x19\n\x11\x63lientTimestampMS\x18\x05 \x01(\x03\x12\x19\n\x11serverTimestampMS\x18\x06 \x01(\x03\"\x9b\x01\n\x17MessageAddOnContextInfo\x12\"\n\x1amessageAddOnDurationInSecs\x18\x01 \x01(\r\x12\\\n\x16messageAddOnExpiryType\x18\x02 \x01(\x0e\x32<.WAWebProtobufsE2E.MessageContextInfo.MessageAddonExpiryType\".\n\x12PremiumMessageInfo\x12\x18\n\x10serverCampaignID\x18\x01 \x01(\t\"\xb2\x01\n\rEventResponse\x12\x35\n\x17\x65ventResponseMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x13\n\x0btimestampMS\x18\x02 \x01(\x03\x12\x45\n\x14\x65ventResponseMessage\x18\x03 \x01(\x0b\x32\'.WAWebProtobufsE2E.EventResponseMessage\x12\x0e\n\x06unread\x18\x04 \x01(\x08\"\x8c\x01\n\rLegacyMessage\x12\x45\n\x14\x65ventResponseMessage\x18\x01 \x01(\x0b\x32\'.WAWebProtobufsE2E.EventResponseMessage\x12\x34\n\x08pollVote\x18\x02 \x01(\x0b\x32\".WAWebProtobufsE2E.PollVoteMessage\"H\n\x14StatusMentionMessage\x12\x30\n\x0cquotedStatus\x18\x01 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\"L\n\x08\x43itation\x12\r\n\x05title\x18\x01 \x02(\t\x12\x10\n\x08subtitle\x18\x02 \x02(\t\x12\r\n\x05\x63msID\x18\x03 \x02(\t\x12\x10\n\x08imageURL\x18\x04 \x02(\tB!Z\x1fgo.mau.fi/whatsmeow/proto/waWeb')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waWeb.WAWebProtobufsWeb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\037go.mau.fi/whatsmeow/proto/waWeb'
  _globals['_WEBMESSAGEINFO']._serialized_start=109
  _globals['_WEBMESSAGEINFO']._serialized_end=10124
  _globals['_WEBMESSAGEINFO_BIZPRIVACYSTATUS']._serialized_start=2563
  _globals['_WEBMESSAGEINFO_BIZPRIVACYSTATUS']._serialized_end=2624
  _globals['_WEBMESSAGEINFO_STUBTYPE']._serialized_start=2627
  _globals['_WEBMESSAGEINFO_STUBTYPE']._serialized_end=10034
  _globals['_WEBMESSAGEINFO_STATUS']._serialized_start=10036
  _globals['_WEBMESSAGEINFO_STATUS']._serialized_end=10124
  _globals['_PAYMENTINFO']._serialized_start=10127
  _globals['_PAYMENTINFO']._serialized_end=11555
  _globals['_PAYMENTINFO_TXNSTATUS']._serialized_start=10640
  _globals['_PAYMENTINFO_TXNSTATUS']._serialized_end=11305
  _globals['_PAYMENTINFO_STATUS']._serialized_start=11308
  _globals['_PAYMENTINFO_STATUS']._serialized_end=11512
  _globals['_PAYMENTINFO_CURRENCY']._serialized_start=11514
  _globals['_PAYMENTINFO_CURRENCY']._serialized_end=11555
  _globals['_WEBFEATURES']._serialized_start=11558
  _globals['_WEBFEATURES']._serialized_end=14493
  _globals['_WEBFEATURES_FLAG']._serialized_start=14418
  _globals['_WEBFEATURES_FLAG']._serialized_end=14493
  _globals['_PININCHAT']._serialized_start=14496
  _globals['_PININCHAT']._serialized_end=14784
  _globals['_PININCHAT_TYPE']._serialized_start=14724
  _globals['_PININCHAT_TYPE']._serialized_end=14784
  _globals['_MESSAGEADDON']._serialized_start=14787
  _globals['_MESSAGEADDON']._serialized_end=15316
  _globals['_MESSAGEADDON_MESSAGEADDONTYPE']._serialized_start=15215
  _globals['_MESSAGEADDON_MESSAGEADDONTYPE']._serialized_end=15316
  _globals['_COMMENTMETADATA']._serialized_start=15318
  _globals['_COMMENTMETADATA']._serialized_end=15403
  _globals['_WEBNOTIFICATIONSINFO']._serialized_start=15406
  _globals['_WEBNOTIFICATIONSINFO']._serialized_end=15555
  _globals['_NOTIFICATIONMESSAGEINFO']._serialized_start=15558
  _globals['_NOTIFICATIONMESSAGEINFO']._serialized_end=15710
  _globals['_REPORTINGTOKENINFO']._serialized_start=15712
  _globals['_REPORTINGTOKENINFO']._serialized_end=15754
  _globals['_MEDIADATA']._serialized_start=15756
  _globals['_MEDIADATA']._serialized_end=15786
  _globals['_PHOTOCHANGE']._serialized_start=15788
  _globals['_PHOTOCHANGE']._serialized_end=15857
  _globals['_STATUSPSA']._serialized_start=15859
  _globals['_STATUSPSA']._serialized_end=15927
  _globals['_USERRECEIPT']._serialized_start=15930
  _globals['_USERRECEIPT']._serialized_end=16088
  _globals['_REACTION']._serialized_start=16090
  _globals['_REACTION']._serialized_end=16213
  _globals['_POLLUPDATE']._serialized_start=16216
  _globals['_POLLUPDATE']._serialized_end=16400
  _globals['_POLLADDITIONALMETADATA']._serialized_start=16402
  _globals['_POLLADDITIONALMETADATA']._serialized_end=16451
  _globals['_EVENTADDITIONALMETADATA']._serialized_start=16453
  _globals['_EVENTADDITIONALMETADATA']._serialized_end=16495
  _globals['_KEEPINCHAT']._serialized_start=16498
  _globals['_KEEPINCHAT']._serialized_end=16690
  _globals['_MESSAGEADDONCONTEXTINFO']._serialized_start=16693
  _globals['_MESSAGEADDONCONTEXTINFO']._serialized_end=16848
  _globals['_PREMIUMMESSAGEINFO']._serialized_start=16850
  _globals['_PREMIUMMESSAGEINFO']._serialized_end=16896
  _globals['_EVENTRESPONSE']._serialized_start=16899
  _globals['_EVENTRESPONSE']._serialized_end=17077
  _globals['_LEGACYMESSAGE']._serialized_start=17080
  _globals['_LEGACYMESSAGE']._serialized_end=17220
  _globals['_STATUSMENTIONMESSAGE']._serialized_start=17222
  _globals['_STATUSMENTIONMESSAGE']._serialized_end=17294
  _globals['_CITATION']._serialized_start=17296
  _globals['_CITATION']._serialized_end=17372
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class WAMediaTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Ancillary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Thumbnail(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class DownloadableThumbnail(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                FILESHA256_FIELD_NUMBER: builtins.int
                FILEENCSHA256_FIELD_NUMBER: builtins.int
                DIRECTPATH_FIELD_NUMBER: builtins.int
                MEDIAKEY_FIELD_NUMBER: builtins.int
                MEDIAKEYTIMESTAMP_FIELD_NUMBER: builtins.int
                OBJECTID_FIELD_NUMBER: builtins.int
                THUMBNAILSCANSSIDECAR_FIELD_NUMBER: builtins.int
                THUMBNAILSCANLENGTHS_FIELD_NUMBER: builtins.int
                fileSHA256: builtins.bytes
                fileEncSHA256: builtins.bytes
                directPath: builtins.str
                mediaKey: builtins.bytes
                mediaKeyTimestamp: builtins.int
                objectID: builtins.str
                thumbnailScansSidecar: builtins.bytes
                @property
                def thumbnailScanLengths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
                def __init__(
                    self,
                    *,
                    fileSHA256: builtins.bytes | None = ...,
                    fileEncSHA256: builtins.bytes | None = ...,
                    directPath: builtins.str | None = ...,
                    mediaKey: builtins.bytes | None = ...,
                    mediaKeyTimestamp: builtins.int | None = ...,
                    objectID: builtins.str | None = ...,
                    thumbnailScansSidecar: builtins.bytes | None = ...,
                    thumbnailScanLengths: collections.abc.Iterable[builtins.int] | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID", "thumbnailScansSidecar", b"thumbnailScansSidecar"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID", "thumbnailScanLengths", b"thumbnailScanLengths", "thumbnailScansSidecar", b"thumbnailScansSidecar"]) -> None: ...

            JPEGTHUMBNAIL_FIELD_NUMBER: builtins.int
            DOWNLOADABLETHUMBNAIL_FIELD_NUMBER: builtins.int
            THUMBNAILWIDTH_FIELD_NUMBER: builtins.int
            THUMBNAILHEIGHT_FIELD_NUMBER: builtins.int
            JPEGThumbnail: builtins.bytes
            thumbnailWidth: builtins.int
            thumbnailHeight: builtins.int
            @property
            def downloadableThumbnail(self) -> global___WAMediaTransport.Ancillary.Thumbnail.DownloadableThumbnail: ...
            def __init__(
                self,
                *,
                JPEGThumbnail: builtins.bytes | None = ...,
                downloadableThumbnail: global___WAMediaTransport.Ancillary.Thumbnail.DownloadableThumbnail | None = ...,
                thumbnailWidth: builtins.int | None = ...,
                thumbnailHeight: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["JPEGThumbnail", b"JPEGThumbnail", "downloadableThumbnail", b"downloadableThumbnail", "thumbnailHeight", b"thumbnailHeight", "thumbnailWidth", b"thumbnailWidth"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["JPEGThumbnail", b"JPEGThumbnail", "downloadableThumbnail", b"downloadableThumbnail", "thumbnailHeight", b"thumbnailHeight", "thumbnailWidth", b"thumbnailWidth"]) -> None: ...

        FILELENGTH_FIELD_NUMBER: builtins.int
        MIMETYPE_FIELD_NUMBER: builtins.int
        THUMBNAIL_FIELD_NUMBER: builtins.int
        OBJECTID_FIELD_NUMBER: builtins.int
        fileLength: builtins.int
        mimetype: builtins.str
        objectID: builtins.str
        @property
        def thumbnail(self) -> global___WAMediaTransport.Ancillary.Thumbnail: ...
        def __init__(
            self,
            *,
            fileLength: builtins.int | None = ...,
            mimetype: builtins.str | None = ...,
            thumbnail: global___WAMediaTransport.Ancillary.Thumbnail | None = ...,
            objectID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["fileLength", b"fileLength", "mimetype", b"mimetype", "objectID", b"objectID", "thumbnail", b"thumbnail"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["fileLength", b"fileLength", "mimetype", b"mimetype", "objectID", b"objectID", "thumbnail", b"thumbnail"]) -> None: ...

    @typing.final
    class Integral(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILESHA256_FIELD_NUMBER: builtins.int
        MEDIAKEY_FIELD_NUMBER: builtins.int
        FILEENCSHA256_FIELD_NUMBER: builtins.int
        DIRECTPATH_FIELD_NUMBER: builtins.int
        MEDIAKEYTIMESTAMP_FIELD_NUMBER: builtins.int
        fileSHA256: builtins.bytes
        mediaKey: builtins.bytes
        fileEncSHA256: builtins.bytes
        directPath: builtins.str
        mediaKeyTimestamp: builtins.int
        def __init__(
            self,
            *,
            fileSHA256: builtins.bytes | None = ...,
            mediaKey: builtins.bytes | None = ...,
            fileEncSHA256: builtins.bytes | None = ...,
            directPath: builtins.str | None = ...,
            mediaKeyTimestamp: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp"]) -> None: ...

    INTEGRAL_FIELD_NUMBER: builtins.int
    ANCILLARY_FIELD_NUMBER: builtins.int
    @property
    def integral(self) -> global___WAMediaTransport.Integral: ...
    @property
    def ancillary(self) -> global___WAMediaTransport.Ancillary: ...
    def __init__(
        self,
        *,
        integral: global___WAMediaTransport.Integral | None = ...,
        ancillary: global___WAMediaTransport.Ancillary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

global___WAMediaTransport = WAMediaTransport

@typing.final
class ImageTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Ancillary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _HdType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _HdTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ImageTransport.Ancillary._HdType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            NONE: ImageTransport.Ancillary._HdType.ValueType  # 0
            LQ_4K: ImageTransport.Ancillary._HdType.ValueType  # 1
            HQ_4K: ImageTransport.Ancillary._HdType.ValueType  # 2

        class HdType(_HdType, metaclass=_HdTypeEnumTypeWrapper): ...
        NONE: ImageTransport.Ancillary.HdType.ValueType  # 0
        LQ_4K: ImageTransport.Ancillary.HdType.ValueType  # 1
        HQ_4K: ImageTransport.Ancillary.HdType.ValueType  # 2

        HEIGHT_FIELD_NUMBER: builtins.int
        WIDTH_FIELD_NUMBER: builtins.int
        SCANSSIDECAR_FIELD_NUMBER: builtins.int
        SCANLENGTHS_FIELD_NUMBER: builtins.int
        MIDQUALITYFILESHA256_FIELD_NUMBER: builtins.int
        HDTYPE_FIELD_NUMBER: builtins.int
        MEMORIESCONCEPTSCORES_FIELD_NUMBER: builtins.int
        MEMORIESCONCEPTIDS_FIELD_NUMBER: builtins.int
        height: builtins.int
        width: builtins.int
        scansSidecar: builtins.bytes
        midQualityFileSHA256: builtins.bytes
        hdType: global___ImageTransport.Ancillary.HdType.ValueType
        @property
        def scanLengths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
        @property
        def memoriesConceptScores(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
        @property
        def memoriesConceptIDs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
        def __init__(
            self,
            *,
            height: builtins.int | None = ...,
            width: builtins.int | None = ...,
            scansSidecar: builtins.bytes | None = ...,
            scanLengths: collections.abc.Iterable[builtins.int] | None = ...,
            midQualityFileSHA256: builtins.bytes | None = ...,
            hdType: global___ImageTransport.Ancillary.HdType.ValueType | None = ...,
            memoriesConceptScores: collections.abc.Iterable[builtins.float] | None = ...,
            memoriesConceptIDs: collections.abc.Iterable[builtins.int] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["hdType", b"hdType", "height", b"height", "midQualityFileSHA256", b"midQualityFileSHA256", "scansSidecar", b"scansSidecar", "width", b"width"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["hdType", b"hdType", "height", b"height", "memoriesConceptIDs", b"memoriesConceptIDs", "memoriesConceptScores", b"memoriesConceptScores", "midQualityFileSHA256", b"midQualityFileSHA256", "scanLengths", b"scanLengths", "scansSidecar", b"scansSidecar", "width", b"width"]) -> None: ...

    @typing.final
    class Integral(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSPORT_FIELD_NUMBER: builtins.int
        @property
        def transport(self) -> global___WAMediaTransport: ...
        def __init__(
            self,
            *,
            transport: global___WAMediaTransport | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["transport", b"transport"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["transport", b"transport"]) -> None: ...

    INTEGRAL_FIELD_NUMBER: builtins.int
    ANCILLARY_FIELD_NUMBER: builtins.int
    @property
    def integral(self) -> global___ImageTransport.Integral: ...
    @property
    def ancillary(self) -> global___ImageTransport.Ancillary: ...
    def __init__(
        self,
        *,
        integral: global___ImageTransport.Integral | None = ...,
        ancillary: global___ImageTransport.Ancillary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

global___ImageTransport = ImageTransport

@typing.final
class VideoTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Ancillary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Attribution:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _AttributionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VideoTransport.Ancillary._Attribution.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            NONE: VideoTransport.Ancillary._Attribution.ValueType  # 0
            GIPHY: VideoTransport.Ancillary._Attribution.ValueType  # 1
            TENOR: VideoTransport.Ancillary._Attribution.ValueType  # 2

        class Attribution(_Attribution, metaclass=_AttributionEnumTypeWrapper): ...
        NONE: VideoTransport.Ancillary.Attribution.ValueType  # 0
        GIPHY: VideoTransport.Ancillary.Attribution.ValueType  # 1
        TENOR: VideoTransport.Ancillary.Attribution.ValueType  # 2

        SECONDS_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        GIFPLAYBACK_FIELD_NUMBER: builtins.int
        HEIGHT_FIELD_NUMBER: builtins.int
        WIDTH_FIELD_NUMBER: builtins.int
        SIDECAR_FIELD_NUMBER: builtins.int
        GIFATTRIBUTION_FIELD_NUMBER: builtins.int
        ACCESSIBILITYLABEL_FIELD_NUMBER: builtins.int
        ISHD_FIELD_NUMBER: builtins.int
        seconds: builtins.int
        gifPlayback: builtins.bool
        height: builtins.int
        width: builtins.int
        sidecar: builtins.bytes
        gifAttribution: global___VideoTransport.Ancillary.Attribution.ValueType
        accessibilityLabel: builtins.str
        isHd: builtins.bool
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            seconds: builtins.int | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
            gifPlayback: builtins.bool | None = ...,
            height: builtins.int | None = ...,
            width: builtins.int | None = ...,
            sidecar: builtins.bytes | None = ...,
            gifAttribution: global___VideoTransport.Ancillary.Attribution.ValueType | None = ...,
            accessibilityLabel: builtins.str | None = ...,
            isHd: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["accessibilityLabel", b"accessibilityLabel", "caption", b"caption", "gifAttribution", b"gifAttribution", "gifPlayback", b"gifPlayback", "height", b"height", "isHd", b"isHd", "seconds", b"seconds", "sidecar", b"sidecar", "width", b"width"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["accessibilityLabel", b"accessibilityLabel", "caption", b"caption", "gifAttribution", b"gifAttribution", "gifPlayback", b"gifPlayback", "height", b"height", "isHd", b"isHd", "seconds", b"seconds", "sidecar", b"sidecar", "width", b"width"]) -> None: ...

    @typing.final
    class Integral(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSPORT_FIELD_NUMBER: builtins.int
        @property
        def transport(self) -> global___WAMediaTransport: ...
        def __init__(
            self,
            *,
            transport: global___WAMediaTransport | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["transport", b"transport"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["transport", b"transport"]) -> None: ...

    INTEGRAL_FIELD_NUMBER: builtins.int
    ANCILLARY_FIELD_NUMBER: builtins.int
    @property
    def integral(self) -> global___VideoTransport.Integral: ...
    @property
    def ancillary(self) -> global___VideoTransport.Ancillary: ...
    def __init__(
        self,
        *,
        integral: global___VideoTransport.Integral | None = ...,
        ancillary: global___VideoTransport.Ancillary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

global___VideoTransport = VideoTransport

@typing.final
class AudioTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Ancillary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class AvatarAudio(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _AnimationsType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _AnimationsTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AudioTransport.Ancillary.AvatarAudio._AnimationsType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                TALKING_A: AudioTransport.Ancillary.AvatarAudio._AnimationsType.ValueType  # 0
                IDLE_A: AudioTransport.Ancillary.AvatarAudio._AnimationsType.ValueType  # 1
                TALKING_B: AudioTransport.Ancillary.AvatarAudio._AnimationsType.ValueType  # 2
                IDLE_B: AudioTransport.Ancillary.AvatarAudio._AnimationsType.ValueType  # 3
                BACKGROUND: AudioTransport.Ancillary.AvatarAudio._AnimationsType.ValueType  # 4

            class AnimationsType(_AnimationsType, metaclass=_AnimationsTypeEnumTypeWrapper): ...
            TALKING_A: AudioTransport.Ancillary.AvatarAudio.AnimationsType.ValueType  # 0
            IDLE_A: AudioTransport.Ancillary.AvatarAudio.AnimationsType.ValueType  # 1
            TALKING_B: AudioTransport.Ancillary.AvatarAudio.AnimationsType.ValueType  # 2
            IDLE_B: AudioTransport.Ancillary.AvatarAudio.AnimationsType.ValueType  # 3
            BACKGROUND: AudioTransport.Ancillary.AvatarAudio.AnimationsType.ValueType  # 4

            @typing.final
            class DownloadableAvatarAnimations(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                FILESHA256_FIELD_NUMBER: builtins.int
                FILEENCSHA256_FIELD_NUMBER: builtins.int
                DIRECTPATH_FIELD_NUMBER: builtins.int
                MEDIAKEY_FIELD_NUMBER: builtins.int
                MEDIAKEYTIMESTAMP_FIELD_NUMBER: builtins.int
                OBJECTID_FIELD_NUMBER: builtins.int
                ANIMATIONSTYPE_FIELD_NUMBER: builtins.int
                fileSHA256: builtins.bytes
                fileEncSHA256: builtins.bytes
                directPath: builtins.str
                mediaKey: builtins.bytes
                mediaKeyTimestamp: builtins.int
                objectID: builtins.str
                animationsType: global___AudioTransport.Ancillary.AvatarAudio.AnimationsType.ValueType
                def __init__(
                    self,
                    *,
                    fileSHA256: builtins.bytes | None = ...,
                    fileEncSHA256: builtins.bytes | None = ...,
                    directPath: builtins.str | None = ...,
                    mediaKey: builtins.bytes | None = ...,
                    mediaKeyTimestamp: builtins.int | None = ...,
                    objectID: builtins.str | None = ...,
                    animationsType: global___AudioTransport.Ancillary.AvatarAudio.AnimationsType.ValueType | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["animationsType", b"animationsType", "directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["animationsType", b"animationsType", "directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID"]) -> None: ...

            POSEID_FIELD_NUMBER: builtins.int
            AVATARANIMATIONS_FIELD_NUMBER: builtins.int
            poseID: builtins.int
            @property
            def avatarAnimations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudioTransport.Ancillary.AvatarAudio.DownloadableAvatarAnimations]: ...
            def __init__(
                self,
                *,
                poseID: builtins.int | None = ...,
                avatarAnimations: collections.abc.Iterable[global___AudioTransport.Ancillary.AvatarAudio.DownloadableAvatarAnimations] | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["poseID", b"poseID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["avatarAnimations", b"avatarAnimations", "poseID", b"poseID"]) -> None: ...

        SECONDS_FIELD_NUMBER: builtins.int
        AVATARAUDIO_FIELD_NUMBER: builtins.int
        seconds: builtins.int
        @property
        def avatarAudio(self) -> global___AudioTransport.Ancillary.AvatarAudio: ...
        def __init__(
            self,
            *,
            seconds: builtins.int | None = ...,
            avatarAudio: global___AudioTransport.Ancillary.AvatarAudio | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["avatarAudio", b"avatarAudio", "seconds", b"seconds"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["avatarAudio", b"avatarAudio", "seconds", b"seconds"]) -> None: ...

    @typing.final
    class Integral(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _AudioFormat:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _AudioFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AudioTransport.Integral._AudioFormat.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: AudioTransport.Integral._AudioFormat.ValueType  # 0
            OPUS: AudioTransport.Integral._AudioFormat.ValueType  # 1

        class AudioFormat(_AudioFormat, metaclass=_AudioFormatEnumTypeWrapper): ...
        UNKNOWN: AudioTransport.Integral.AudioFormat.ValueType  # 0
        OPUS: AudioTransport.Integral.AudioFormat.ValueType  # 1

        TRANSPORT_FIELD_NUMBER: builtins.int
        AUDIOFORMAT_FIELD_NUMBER: builtins.int
        audioFormat: global___AudioTransport.Integral.AudioFormat.ValueType
        @property
        def transport(self) -> global___WAMediaTransport: ...
        def __init__(
            self,
            *,
            transport: global___WAMediaTransport | None = ...,
            audioFormat: global___AudioTransport.Integral.AudioFormat.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["audioFormat", b"audioFormat", "transport", b"transport"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["audioFormat", b"audioFormat", "transport", b"transport"]) -> None: ...

    INTEGRAL_FIELD_NUMBER: builtins.int
    ANCILLARY_FIELD_NUMBER: builtins.int
    @property
    def integral(self) -> global___AudioTransport.Integral: ...
    @property
    def ancillary(self) -> global___AudioTransport.Ancillary: ...
    def __init__(
        self,
        *,
        integral: global___AudioTransport.Integral | None = ...,
        ancillary: global___AudioTransport.Ancillary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

global___AudioTransport = AudioTransport

@typing.final
class DocumentTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Ancillary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PAGECOUNT_FIELD_NUMBER: builtins.int
        pageCount: builtins.int
        def __init__(
            self,
            *,
            pageCount: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["pageCount", b"pageCount"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["pageCount", b"pageCount"]) -> None: ...

    @typing.final
    class Integral(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSPORT_FIELD_NUMBER: builtins.int
        @property
        def transport(self) -> global___WAMediaTransport: ...
        def __init__(
            self,
            *,
            transport: global___WAMediaTransport | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["transport", b"transport"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["transport", b"transport"]) -> None: ...

    INTEGRAL_FIELD_NUMBER: builtins.int
    ANCILLARY_FIELD_NUMBER: builtins.int
    @property
    def integral(self) -> global___DocumentTransport.Integral: ...
    @property
    def ancillary(self) -> global___DocumentTransport.Ancillary: ...
    def __init__(
        self,
        *,
        integral: global___DocumentTransport.Integral | None = ...,
        ancillary: global___DocumentTransport.Ancillary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

global___DocumentTransport = DocumentTransport

@typing.final
class StickerTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Ancillary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PAGECOUNT_FIELD_NUMBER: builtins.int
        HEIGHT_FIELD_NUMBER: builtins.int
        WIDTH_FIELD_NUMBER: builtins.int
        FIRSTFRAMELENGTH_FIELD_NUMBER: builtins.int
        FIRSTFRAMESIDECAR_FIELD_NUMBER: builtins.int
        MUSTACHETEXT_FIELD_NUMBER: builtins.int
        ISTHIRDPARTY_FIELD_NUMBER: builtins.int
        RECEIVERFETCHID_FIELD_NUMBER: builtins.int
        ACCESSIBILITYLABEL_FIELD_NUMBER: builtins.int
        pageCount: builtins.int
        height: builtins.int
        width: builtins.int
        firstFrameLength: builtins.int
        firstFrameSidecar: builtins.bytes
        mustacheText: builtins.str
        isThirdParty: builtins.bool
        receiverFetchID: builtins.str
        accessibilityLabel: builtins.str
        def __init__(
            self,
            *,
            pageCount: builtins.int | None = ...,
            height: builtins.int | None = ...,
            width: builtins.int | None = ...,
            firstFrameLength: builtins.int | None = ...,
            firstFrameSidecar: builtins.bytes | None = ...,
            mustacheText: builtins.str | None = ...,
            isThirdParty: builtins.bool | None = ...,
            receiverFetchID: builtins.str | None = ...,
            accessibilityLabel: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["accessibilityLabel", b"accessibilityLabel", "firstFrameLength", b"firstFrameLength", "firstFrameSidecar", b"firstFrameSidecar", "height", b"height", "isThirdParty", b"isThirdParty", "mustacheText", b"mustacheText", "pageCount", b"pageCount", "receiverFetchID", b"receiverFetchID", "width", b"width"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["accessibilityLabel", b"accessibilityLabel", "firstFrameLength", b"firstFrameLength", "firstFrameSidecar", b"firstFrameSidecar", "height", b"height", "isThirdParty", b"isThirdParty", "mustacheText", b"mustacheText", "pageCount", b"pageCount", "receiverFetchID", b"receiverFetchID", "width", b"width"]) -> None: ...

    @typing.final
    class Integral(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSPORT_FIELD_NUMBER: builtins.int
        ISANIMATED_FIELD_NUMBER: builtins.int
        RECEIVERFETCHID_FIELD_NUMBER: builtins.int
        isAnimated: builtins.bool
        receiverFetchID: builtins.str
        @property
        def transport(self) -> global___WAMediaTransport: ...
        def __init__(
            self,
            *,
            transport: global___WAMediaTransport | None = ...,
            isAnimated: builtins.bool | None = ...,
            receiverFetchID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["isAnimated", b"isAnimated", "receiverFetchID", b"receiverFetchID", "transport", b"transport"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["isAnimated", b"isAnimated", "receiverFetchID", b"receiverFetchID", "transport", b"transport"]) -> None: ...

    INTEGRAL_FIELD_NUMBER: builtins.int
    ANCILLARY_FIELD_NUMBER: builtins.int
    @property
    def integral(self) -> global___StickerTransport.Integral: ...
    @property
    def ancillary(self) -> global___StickerTransport.Ancillary: ...
    def __init__(
        self,
        *,
        integral: global___StickerTransport.Integral | None = ...,
        ancillary: global___StickerTransport.Ancillary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

global___StickerTransport = StickerTransport

@typing.final
class ContactTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Ancillary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DISPLAYNAME_FIELD_NUMBER: builtins.int
        displayName: builtins.str
        def __init__(
            self,
            *,
            displayName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["displayName", b"displayName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["displayName", b"displayName"]) -> None: ...

    @typing.final
    class Integral(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VCARD_FIELD_NUMBER: builtins.int
        DOWNLOADABLEVCARD_FIELD_NUMBER: builtins.int
        vcard: builtins.str
        @property
        def downloadableVcard(self) -> global___WAMediaTransport: ...
        def __init__(
            self,
            *,
            vcard: builtins.str | None = ...,
            downloadableVcard: global___WAMediaTransport | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["contact", b"contact", "downloadableVcard", b"downloadableVcard", "vcard", b"vcard"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["contact", b"contact", "downloadableVcard", b"downloadableVcard", "vcard", b"vcard"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["contact", b"contact"]) -> typing.Literal["vcard", "downloadableVcard"] | None: ...

    INTEGRAL_FIELD_NUMBER: builtins.int
    ANCILLARY_FIELD_NUMBER: builtins.int
    @property
    def integral(self) -> global___ContactTransport.Integral: ...
    @property
    def ancillary(self) -> global___ContactTransport.Ancillary: ...
    def __init__(
        self,
        *,
        integral: global___ContactTransport.Integral | None = ...,
        ancillary: global___ContactTransport.Ancillary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

global___ContactTransport = ContactTransport



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BizAccountLinkInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AccountType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AccountTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BizAccountLinkInfo._AccountType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENTERPRISE: BizAccountLinkInfo._AccountType.ValueType  # 0

    class AccountType(_AccountType, metaclass=_AccountTypeEnumTypeWrapper): ...
    ENTERPRISE: BizAccountLinkInfo.AccountType.ValueType  # 0

    class _HostStorageType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HostStorageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BizAccountLinkInfo._HostStorageType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ON_PREMISE: BizAccountLinkInfo._HostStorageType.ValueType  # 0
        FACEBOOK: BizAccountLinkInfo._HostStorageType.ValueType  # 1

    class HostStorageType(_HostStorageType, metaclass=_HostStorageTypeEnumTypeWrapper): ...
    ON_PREMISE: BizAccountLinkInfo.HostStorageType.ValueType  # 0
    FACEBOOK: BizAccountLinkInfo.HostStorageType.ValueType  # 1

    WHATSAPPBIZACCTFBID_FIELD_NUMBER: builtins.int
    WHATSAPPACCTNUMBER_FIELD_NUMBER: builtins.int
    ISSUETIME_FIELD_NUMBER: builtins.int
    HOSTSTORAGE_FIELD_NUMBER: builtins.int
    ACCOUNTTYPE_FIELD_NUMBER: builtins.int
    whatsappBizAcctFbid: builtins.int
    whatsappAcctNumber: builtins.str
    issueTime: builtins.int
    hostStorage: global___BizAccountLinkInfo.HostStorageType.ValueType
    accountType: global___BizAccountLinkInfo.AccountType.ValueType
    def __init__(
        self,
        *,
        whatsappBizAcctFbid: builtins.int | None = ...,
        whatsappAcctNumber: builtins.str | None = ...,
        issueTime: builtins.int | None = ...,
        hostStorage: global___BizAccountLinkInfo.HostStorageType.ValueType | None = ...,
        accountType: global___BizAccountLinkInfo.AccountType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["accountType", b"accountType", "hostStorage", b"hostStorage", "issueTime", b"issueTime", "whatsappAcctNumber", b"whatsappAcctNumber", "whatsappBizAcctFbid", b"whatsappBizAcctFbid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accountType", b"accountType", "hostStorage", b"hostStorage", "issueTime", b"issueTime", "whatsappAcctNumber", b"whatsappAcctNumber", "whatsappBizAcctFbid", b"whatsappBizAcctFbid"]) -> None: ...

global___BizAccountLinkInfo = BizAccountLinkInfo

@typing.final
class BizIdentityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ActualActorsType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActualActorsTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BizIdentityInfo._ActualActorsType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SELF: BizIdentityInfo._ActualActorsType.ValueType  # 0
        BSP: BizIdentityInfo._ActualActorsType.ValueType  # 1

    class ActualActorsType(_ActualActorsType, metaclass=_ActualActorsTypeEnumTypeWrapper): ...
    SELF: BizIdentityInfo.ActualActorsType.ValueType  # 0
    BSP: BizIdentityInfo.ActualActorsType.ValueType  # 1

    class _HostStorageType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HostStorageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BizIdentityInfo._HostStorageType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ON_PREMISE: BizIdentityInfo._HostStorageType.ValueType  # 0
        FACEBOOK: BizIdentityInfo._HostStorageType.ValueType  # 1

    class HostStorageType(_HostStorageType, metaclass=_HostStorageTypeEnumTypeWrapper): ...
    ON_PREMISE: BizIdentityInfo.HostStorageType.ValueType  # 0
    FACEBOOK: BizIdentityInfo.HostStorageType.ValueType  # 1

    class _VerifiedLevelValue:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VerifiedLevelValueEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BizIdentityInfo._VerifiedLevelValue.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: BizIdentityInfo._VerifiedLevelValue.ValueType  # 0
        LOW: BizIdentityInfo._VerifiedLevelValue.ValueType  # 1
        HIGH: BizIdentityInfo._VerifiedLevelValue.ValueType  # 2

    class VerifiedLevelValue(_VerifiedLevelValue, metaclass=_VerifiedLevelValueEnumTypeWrapper): ...
    UNKNOWN: BizIdentityInfo.VerifiedLevelValue.ValueType  # 0
    LOW: BizIdentityInfo.VerifiedLevelValue.ValueType  # 1
    HIGH: BizIdentityInfo.VerifiedLevelValue.ValueType  # 2

    VLEVEL_FIELD_NUMBER: builtins.int
    VNAMECERT_FIELD_NUMBER: builtins.int
    SIGNED_FIELD_NUMBER: builtins.int
    REVOKED_FIELD_NUMBER: builtins.int
    HOSTSTORAGE_FIELD_NUMBER: builtins.int
    ACTUALACTORS_FIELD_NUMBER: builtins.int
    PRIVACYMODETS_FIELD_NUMBER: builtins.int
    FEATURECONTROLS_FIELD_NUMBER: builtins.int
    vlevel: global___BizIdentityInfo.VerifiedLevelValue.ValueType
    signed: builtins.bool
    revoked: builtins.bool
    hostStorage: global___BizIdentityInfo.HostStorageType.ValueType
    actualActors: global___BizIdentityInfo.ActualActorsType.ValueType
    privacyModeTS: builtins.int
    featureControls: builtins.int
    @property
    def vnameCert(self) -> global___VerifiedNameCertificate: ...
    def __init__(
        self,
        *,
        vlevel: global___BizIdentityInfo.VerifiedLevelValue.ValueType | None = ...,
        vnameCert: global___VerifiedNameCertificate | None = ...,
        signed: builtins.bool | None = ...,
        revoked: builtins.bool | None = ...,
        hostStorage: global___BizIdentityInfo.HostStorageType.ValueType | None = ...,
        actualActors: global___BizIdentityInfo.ActualActorsType.ValueType | None = ...,
        privacyModeTS: builtins.int | None = ...,
        featureControls: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["actualActors", b"actualActors", "featureControls", b"featureControls", "hostStorage", b"hostStorage", "privacyModeTS", b"privacyModeTS", "revoked", b"revoked", "signed", b"signed", "vlevel", b"vlevel", "vnameCert", b"vnameCert"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["actualActors", b"actualActors", "featureControls", b"featureControls", "hostStorage", b"hostStorage", "privacyModeTS", b"privacyModeTS", "revoked", b"revoked", "signed", b"signed", "vlevel", b"vlevel", "vnameCert", b"vnameCert"]) -> None: ...

global___BizIdentityInfo = BizIdentityInfo

@typing.final
class LocalizedName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LG_FIELD_NUMBER: builtins.int
    LC_FIELD_NUMBER: builtins.int
    VERIFIEDNAME_FIELD_NUMBER: builtins.int
    lg: builtins.str
    lc: builtins.str
    verifiedName: builtins.str
    def __init__(
        self,
        *,
        lg: builtins.str | None = ...,
        lc: builtins.str | None = ...,
        verifiedName: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lc", b"lc", "lg", b"lg", "verifiedName", b"verifiedName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["lc", b"lc", "lg", b"lg", "verifiedName", b"verifiedName"]) -> None: ...

global___LocalizedName = LocalizedName

@typing.final
class VerifiedNameCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Details(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERIAL_FIELD_NUMBER: builtins.int
        ISSUER_FIELD_NUMBER: builtins.int
        VERIFIEDNAME_FIELD_NUMBER: builtins.int
        LOCALIZEDNAMES_FIELD_NUMBER: builtins.int
        ISSUETIME_FIELD_NUMBER: builtins.int
        serial: builtins.int
        issuer: builtins.str
        verifiedName: builtins.str
        issueTime: builtins.int
        @property
        def localizedNames(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LocalizedName]: ...
        def __init__(
            self,
            *,
            serial: builtins.int | None = ...,
            issuer: builtins.str | None = ...,
            verifiedName: builtins.str | None = ...,
            localizedNames: collections.abc.Iterable[global___LocalizedName] | None = ...,
            issueTime: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["issueTime", b"issueTime", "issuer", b"issuer", "serial", b"serial", "verifiedName", b"verifiedName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["issueTime", b"issueTime", "issuer", b"issuer", "localizedNames", b"localizedNames", "serial", b"serial", "verifiedName", b"verifiedName"]) -> None: ...

    DETAILS_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    SERVERSIGNATURE_FIELD_NUMBER: builtins.int
    details: builtins.bytes
    signature: builtins.bytes
    serverSignature: builtins.bytes
    def __init__(
        self,
        *,
        details: builtins.bytes | None = ...,
        signature: builtins.bytes | None = ...,
        serverSignature: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["details", b"details", "serverSignature", b"serverSignature", "signature", b"signature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["details", b"details", "serverSignature", b"serverSignature", "signature", b"signature"]) -> None: ...

global___VerifiedNameCertificate = VerifiedNameCertificate

@typing.final
class BizAccountPayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VNAMECERT_FIELD_NUMBER: builtins.int
    BIZACCTLINKINFO_FIELD_NUMBER: builtins.int
    bizAcctLinkInfo: builtins.bytes
    @property
    def vnameCert(self) -> global___VerifiedNameCertificate: ...
    def __init__(
        self,
        *,
        vnameCert: global___VerifiedNameCertificate | None = ...,
        bizAcctLinkInfo: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bizAcctLinkInfo", b"bizAcctLinkInfo", "vnameCert", b"vnameCert"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bizAcctLinkInfo", b"bizAcctLinkInfo", "vnameCert", b"vnameCert"]) -> None: ...

global___BizAccountPayload = BizAccountPayload



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FutureProofBehavior:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FutureProofBehaviorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FutureProofBehavior.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PLACEHOLDER: _FutureProofBehavior.ValueType  # 0
    NO_PLACEHOLDER: _FutureProofBehavior.ValueType  # 1
    IGNORE: _FutureProofBehavior.ValueType  # 2

class FutureProofBehavior(_FutureProofBehavior, metaclass=_FutureProofBehaviorEnumTypeWrapper): ...

PLACEHOLDER: FutureProofBehavior.ValueType  # 0
NO_PLACEHOLDER: FutureProofBehavior.ValueType  # 1
IGNORE: FutureProofBehavior.ValueType  # 2
global___FutureProofBehavior = FutureProofBehavior

@typing.final
class MessageKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMOTEJID_FIELD_NUMBER: builtins.int
    FROMME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    remoteJID: builtins.str
    fromMe: builtins.bool
    ID: builtins.str
    participant: builtins.str
    def __init__(
        self,
        *,
        remoteJID: builtins.str | None = ...,
        fromMe: builtins.bool | None = ...,
        ID: builtins.str | None = ...,
        participant: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "fromMe", b"fromMe", "participant", b"participant", "remoteJID", b"remoteJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "fromMe", b"fromMe", "participant", b"participant", "remoteJID", b"remoteJID"]) -> None: ...

global___MessageKey = MessageKey

@typing.final
class Command(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CommandType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CommandTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Command._CommandType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EVERYONE: Command._CommandType.ValueType  # 1
        SILENT: Command._CommandType.ValueType  # 2
        AI: Command._CommandType.ValueType  # 3
        AI_IMAGINE: Command._CommandType.ValueType  # 4

    class CommandType(_CommandType, metaclass=_CommandTypeEnumTypeWrapper): ...
    EVERYONE: Command.CommandType.ValueType  # 1
    SILENT: Command.CommandType.ValueType  # 2
    AI: Command.CommandType.ValueType  # 3
    AI_IMAGINE: Command.CommandType.ValueType  # 4

    COMMANDTYPE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    VALIDATIONTOKEN_FIELD_NUMBER: builtins.int
    commandType: global___Command.CommandType.ValueType
    offset: builtins.int
    length: builtins.int
    validationToken: builtins.str
    def __init__(
        self,
        *,
        commandType: global___Command.CommandType.ValueType | None = ...,
        offset: builtins.int | None = ...,
        length: builtins.int | None = ...,
        validationToken: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["commandType", b"commandType", "length", b"length", "offset", b"offset", "validationToken", b"validationToken"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["commandType", b"commandType", "length", b"length", "offset", b"offset", "validationToken", b"validationToken"]) -> None: ...

global___Command = Command

@typing.final
class Mention(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MentionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MentionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Mention._MentionType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PROFILE: Mention._MentionType.ValueType  # 0

    class MentionType(_MentionType, metaclass=_MentionTypeEnumTypeWrapper): ...
    PROFILE: Mention.MentionType.ValueType  # 0

    MENTIONTYPE_FIELD_NUMBER: builtins.int
    MENTIONEDJID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    mentionType: global___Mention.MentionType.ValueType
    mentionedJID: builtins.str
    offset: builtins.int
    length: builtins.int
    def __init__(
        self,
        *,
        mentionType: global___Mention.MentionType.ValueType | None = ...,
        mentionedJID: builtins.str | None = ...,
        offset: builtins.int | None = ...,
        length: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["length", b"length", "mentionType", b"mentionType", "mentionedJID", b"mentionedJID", "offset", b"offset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["length", b"length", "mentionType", b"mentionType", "mentionedJID", b"mentionedJID", "offset", b"offset"]) -> None: ...

global___Mention = Mention

@typing.final
class MessageText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    MENTIONEDJID_FIELD_NUMBER: builtins.int
    COMMANDS_FIELD_NUMBER: builtins.int
    MENTIONS_FIELD_NUMBER: builtins.int
    text: builtins.str
    @property
    def mentionedJID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def commands(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Command]: ...
    @property
    def mentions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Mention]: ...
    def __init__(
        self,
        *,
        text: builtins.str | None = ...,
        mentionedJID: collections.abc.Iterable[builtins.str] | None = ...,
        commands: collections.abc.Iterable[global___Command] | None = ...,
        mentions: collections.abc.Iterable[global___Mention] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["commands", b"commands", "mentionedJID", b"mentionedJID", "mentions", b"mentions", "text", b"text"]) -> None: ...

global___MessageText = MessageText

@typing.final
class SubProtocol(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAYLOAD_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    payload: builtins.bytes
    version: builtins.int
    def __init__(
        self,
        *,
        payload: builtins.bytes | None = ...,
        version: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["payload", b"payload", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["payload", b"payload", "version", b"version"]) -> None: ...

global___SubProtocol = SubProtocol

@typing.final
class LimitSharing(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Trigger:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TriggerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LimitSharing._Trigger.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: LimitSharing._Trigger.ValueType  # 0
        CHAT_SETTING: LimitSharing._Trigger.ValueType  # 1
        BIZ_SUPPORTS_FB_HOSTING: LimitSharing._Trigger.ValueType  # 2
        UNKNOWN_GROUP: LimitSharing._Trigger.ValueType  # 3

    class Trigger(_Trigger, metaclass=_TriggerEnumTypeWrapper): ...
    UNKNOWN: LimitSharing.Trigger.ValueType  # 0
    CHAT_SETTING: LimitSharing.Trigger.ValueType  # 1
    BIZ_SUPPORTS_FB_HOSTING: LimitSharing.Trigger.ValueType  # 2
    UNKNOWN_GROUP: LimitSharing.Trigger.ValueType  # 3

    SHARINGLIMITED_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    LIMITSHARINGSETTINGTIMESTAMP_FIELD_NUMBER: builtins.int
    INITIATEDBYME_FIELD_NUMBER: builtins.int
    sharingLimited: builtins.bool
    trigger: global___LimitSharing.Trigger.ValueType
    limitSharingSettingTimestamp: builtins.int
    initiatedByMe: builtins.bool
    def __init__(
        self,
        *,
        sharingLimited: builtins.bool | None = ...,
        trigger: global___LimitSharing.Trigger.ValueType | None = ...,
        limitSharingSettingTimestamp: builtins.int | None = ...,
        initiatedByMe: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["initiatedByMe", b"initiatedByMe", "limitSharingSettingTimestamp", b"limitSharingSettingTimestamp", "sharingLimited", b"sharingLimited", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["initiatedByMe", b"initiatedByMe", "limitSharingSettingTimestamp", b"limitSharingSettingTimestamp", "sharingLimited", b"sharingLimited", "trigger", b"trigger"]) -> None: ...

global___LimitSharing = LimitSharing



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Reportable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MINVERSION_FIELD_NUMBER: builtins.int
    MAXVERSION_FIELD_NUMBER: builtins.int
    NOTREPORTABLEMINVERSION_FIELD_NUMBER: builtins.int
    NEVER_FIELD_NUMBER: builtins.int
    minVersion: builtins.int
    maxVersion: builtins.int
    notReportableMinVersion: builtins.int
    never: builtins.bool
    def __init__(
        self,
        *,
        minVersion: builtins.int = ...,
        maxVersion: builtins.int = ...,
        notReportableMinVersion: builtins.int = ...,
        never: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["maxVersion", b"maxVersion", "minVersion", b"minVersion", "never", b"never", "notReportableMinVersion", b"notReportableMinVersion"]) -> None: ...

global___Reportable = Reportable

@typing.final
class Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FieldEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___Field: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___Field | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FIELD_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.int
    @property
    def field(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___Field]: ...
    def __init__(
        self,
        *,
        field: collections.abc.Mapping[builtins.int, global___Field] | None = ...,
        version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field", b"field", "version", b"version"]) -> None: ...

global___Config = Config

@typing.final
class Field(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SubfieldEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___Field: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___Field | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    MINVERSION_FIELD_NUMBER: builtins.int
    MAXVERSION_FIELD_NUMBER: builtins.int
    NOTREPORTABLEMINVERSION_FIELD_NUMBER: builtins.int
    ISMESSAGE_FIELD_NUMBER: builtins.int
    SUBFIELD_FIELD_NUMBER: builtins.int
    minVersion: builtins.int
    maxVersion: builtins.int
    notReportableMinVersion: builtins.int
    isMessage: builtins.bool
    @property
    def subfield(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___Field]: ...
    def __init__(
        self,
        *,
        minVersion: builtins.int = ...,
        maxVersion: builtins.int = ...,
        notReportableMinVersion: builtins.int = ...,
        isMessage: builtins.bool = ...,
        subfield: collections.abc.Mapping[builtins.int, global___Field] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["isMessage", b"isMessage", "maxVersion", b"maxVersion", "minVersion", b"minVersion", "notReportableMinVersion", b"notReportableMinVersion", "subfield", b"subfield"]) -> None: ...

global___Field = Field



import random
import string
import tempfile


def save_file_to_temp_directory(data: bytes) -> str:
    temp_dir = tempfile.gettempdir()
    random_string = "".join(random.choices(string.ascii_letters + string.digits, k=8))
    temp_file_name = temp_dir + "/" + random_string
    with open(temp_file_name, "wb") as temp_file:
        temp_file.write(data)

    return temp_file_name



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waConsumerApplication/WAConsumerApplication.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waConsumerApplication/WAConsumerApplication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1waConsumerApplication/WAConsumerApplication.proto\x12\x15WAConsumerApplication\x1a\x17waCommon/WACommon.proto\"\xca,\n\x13\x43onsumerApplication\x12\x43\n\x07payload\x18\x01 \x01(\x0b\x32\x32.WAConsumerApplication.ConsumerApplication.Payload\x12\x45\n\x08metadata\x18\x02 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.Metadata\x1a\xcd\x02\n\x07Payload\x12\x45\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x32.WAConsumerApplication.ConsumerApplication.ContentH\x00\x12U\n\x0f\x61pplicationData\x18\x02 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.ApplicationDataH\x00\x12\x43\n\x06signal\x18\x03 \x01(\x0b\x32\x31.WAConsumerApplication.ConsumerApplication.SignalH\x00\x12T\n\x0bsubProtocol\x18\x04 \x01(\x0b\x32=.WAConsumerApplication.ConsumerApplication.SubProtocolPayloadH\x00\x42\t\n\x07payload\x1aH\n\x12SubProtocolPayload\x12\x32\n\x0b\x66utureProof\x18\x01 \x01(\x0e\x32\x1d.WACommon.FutureProofBehavior\x1a\x9d\x01\n\x08Metadata\x12\\\n\x0fspecialTextSize\x18\x01 \x01(\x0e\x32\x43.WAConsumerApplication.ConsumerApplication.Metadata.SpecialTextSize\"3\n\x0fSpecialTextSize\x12\t\n\x05SMALL\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\t\n\x05LARGE\x10\x03\x1a\x08\n\x06Signal\x1as\n\x0f\x41pplicationData\x12J\n\x06revoke\x18\x01 \x01(\x0b\x32\x38.WAConsumerApplication.ConsumerApplication.RevokeMessageH\x00\x42\x14\n\x12\x61pplicationContent\x1a\x9a\x0c\n\x07\x43ontent\x12,\n\x0bmessageText\x18\x01 \x01(\x0b\x32\x15.WACommon.MessageTextH\x00\x12O\n\x0cimageMessage\x18\x02 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.ImageMessageH\x00\x12S\n\x0e\x63ontactMessage\x18\x03 \x01(\x0b\x32\x39.WAConsumerApplication.ConsumerApplication.ContactMessageH\x00\x12U\n\x0flocationMessage\x18\x04 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.LocationMessageH\x00\x12]\n\x13\x65xtendedTextMessage\x18\x05 \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.ExtendedTextMessageH\x00\x12X\n\x11statusTextMessage\x18\x06 \x01(\x0b\x32;.WAConsumerApplication.ConsumerApplication.StatusTextMesageH\x00\x12U\n\x0f\x64ocumentMessage\x18\x07 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.DocumentMessageH\x00\x12O\n\x0c\x61udioMessage\x18\x08 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.AudioMessageH\x00\x12O\n\x0cvideoMessage\x18\t \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.VideoMessageH\x00\x12_\n\x14\x63ontactsArrayMessage\x18\n \x01(\x0b\x32?.WAConsumerApplication.ConsumerApplication.ContactsArrayMessageH\x00\x12]\n\x13liveLocationMessage\x18\x0b \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.LiveLocationMessageH\x00\x12S\n\x0estickerMessage\x18\x0c \x01(\x0b\x32\x39.WAConsumerApplication.ConsumerApplication.StickerMessageH\x00\x12[\n\x12groupInviteMessage\x18\r \x01(\x0b\x32=.WAConsumerApplication.ConsumerApplication.GroupInviteMessageH\x00\x12U\n\x0fviewOnceMessage\x18\x0e \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.ViewOnceMessageH\x00\x12U\n\x0freactionMessage\x18\x10 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.ReactionMessageH\x00\x12]\n\x13pollCreationMessage\x18\x11 \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.PollCreationMessageH\x00\x12Y\n\x11pollUpdateMessage\x18\x12 \x01(\x0b\x32<.WAConsumerApplication.ConsumerApplication.PollUpdateMessageH\x00\x12M\n\x0b\x65\x64itMessage\x18\x13 \x01(\x0b\x32\x36.WAConsumerApplication.ConsumerApplication.EditMessageH\x00\x42\t\n\x07\x63ontent\x1am\n\x0b\x45\x64itMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12&\n\x07message\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x13\n\x0btimestampMS\x18\x03 \x01(\x03\x1a]\n\x14PollAddOptionMessage\x12\x45\n\npollOption\x18\x01 \x03(\x0b\x32\x31.WAConsumerApplication.ConsumerApplication.Option\x1a\x45\n\x0fPollVoteMessage\x12\x17\n\x0fselectedOptions\x18\x01 \x03(\x0c\x12\x19\n\x11senderTimestampMS\x18\x02 \x01(\x03\x1a\x31\n\x0cPollEncValue\x12\x12\n\nencPayload\x18\x01 \x01(\x0c\x12\r\n\x05\x65ncIV\x18\x02 \x01(\x0c\x1a\xdc\x01\n\x11PollUpdateMessage\x12\x34\n\x16pollCreationMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x45\n\x04vote\x18\x02 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.PollEncValue\x12J\n\taddOption\x18\x03 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.PollEncValue\x1a\x97\x01\n\x13PollCreationMessage\x12\x0e\n\x06\x65ncKey\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\x07options\x18\x03 \x03(\x0b\x32\x31.WAConsumerApplication.ConsumerApplication.Option\x12\x1e\n\x16selectableOptionsCount\x18\x04 \x01(\r\x1a\x1c\n\x06Option\x12\x12\n\noptionName\x18\x01 \x01(\t\x1a\xa8\x01\n\x0fReactionMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0bgroupingKey\x18\x03 \x01(\t\x12\x19\n\x11senderTimestampMS\x18\x04 \x01(\x03\x12%\n\x1dreactionMetadataDataclassData\x18\x05 \x01(\t\x12\r\n\x05style\x18\x06 \x01(\x05\x1a\x32\n\rRevokeMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x1a\xc6\x01\n\x0fViewOnceMessage\x12O\n\x0cimageMessage\x18\x01 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.ImageMessageH\x00\x12O\n\x0cvideoMessage\x18\x02 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.VideoMessageH\x00\x42\x11\n\x0fviewOnceContent\x1a\xa6\x01\n\x12GroupInviteMessage\x12\x10\n\x08groupJID\x18\x01 \x01(\t\x12\x12\n\ninviteCode\x18\x02 \x01(\t\x12\x18\n\x10inviteExpiration\x18\x03 \x01(\x03\x12\x11\n\tgroupName\x18\x04 \x01(\t\x12\x15\n\rJPEGThumbnail\x18\x05 \x01(\x0c\x12&\n\x07\x63\x61ption\x18\x06 \x01(\x0b\x32\x15.WACommon.MessageText\x1a\x89\x02\n\x13LiveLocationMessage\x12\x45\n\x08location\x18\x01 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.Location\x12\x18\n\x10\x61\x63\x63uracyInMeters\x18\x02 \x01(\r\x12\x12\n\nspeedInMps\x18\x03 \x01(\x02\x12)\n!degreesClockwiseFromMagneticNorth\x18\x04 \x01(\r\x12&\n\x07\x63\x61ption\x18\x05 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x16\n\x0esequenceNumber\x18\x06 \x01(\x03\x12\x12\n\ntimeOffset\x18\x07 \x01(\r\x1ax\n\x14\x43ontactsArrayMessage\x12\x13\n\x0b\x64isplayName\x18\x01 \x01(\t\x12K\n\x08\x63ontacts\x18\x02 \x03(\x0b\x32\x39.WAConsumerApplication.ConsumerApplication.ContactMessage\x1a\x38\n\x0e\x43ontactMessage\x12&\n\x07\x63ontact\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x1a\xd6\x02\n\x10StatusTextMesage\x12L\n\x04text\x18\x01 \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.ExtendedTextMessage\x12\x10\n\x08textArgb\x18\x06 \x01(\x07\x12\x16\n\x0e\x62\x61\x63kgroundArgb\x18\x07 \x01(\x07\x12R\n\x04\x66ont\x18\x08 \x01(\x0e\x32\x44.WAConsumerApplication.ConsumerApplication.StatusTextMesage.FontType\"v\n\x08\x46ontType\x12\x0e\n\nSANS_SERIF\x10\x00\x12\t\n\x05SERIF\x10\x01\x12\x13\n\x0fNORICAN_REGULAR\x10\x02\x12\x11\n\rBRYNDAN_WRITE\x10\x03\x12\x15\n\x11\x42\x45\x42\x41SNEUE_REGULAR\x10\x04\x12\x10\n\x0cOSWALD_HEAVY\x10\x05\x1a\xb8\x02\n\x13\x45xtendedTextMessage\x12#\n\x04text\x18\x01 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x13\n\x0bmatchedText\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61nonicalURL\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12(\n\tthumbnail\x18\x06 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12_\n\x0bpreviewType\x18\x07 \x01(\x0e\x32J.WAConsumerApplication.ConsumerApplication.ExtendedTextMessage.PreviewType\"\"\n\x0bPreviewType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05VIDEO\x10\x01\x1ai\n\x0fLocationMessage\x12\x45\n\x08location\x18\x01 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.Location\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x1a\x38\n\x0eStickerMessage\x12&\n\x07sticker\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x1aL\n\x0f\x44ocumentMessage\x12\'\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x10\n\x08\x66ileName\x18\x02 \x01(\t\x1a\\\n\x0cVideoMessage\x12$\n\x05video\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12&\n\x07\x63\x61ption\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x1a\x41\n\x0c\x41udioMessage\x12$\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x0b\n\x03PTT\x18\x02 \x01(\x08\x1a\\\n\x0cImageMessage\x12$\n\x05image\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12&\n\x07\x63\x61ption\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x1a\xb5\x01\n\x15InteractiveAnnotation\x12G\n\x08location\x18\x02 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.LocationH\x00\x12I\n\x0fpolygonVertices\x18\x01 \x03(\x0b\x32\x30.WAConsumerApplication.ConsumerApplication.PointB\x08\n\x06\x61\x63tion\x1a\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x1aK\n\x08Location\x12\x17\n\x0f\x64\x65greesLatitude\x18\x01 \x01(\x01\x12\x18\n\x10\x64\x65greesLongitude\x18\x02 \x01(\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x1a\x37\n\x0cMediaPayload\x12\'\n\x08protocol\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocolB1Z/go.mau.fi/whatsmeow/proto/waConsumerApplication')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waConsumerApplication.WAConsumerApplication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/go.mau.fi/whatsmeow/proto/waConsumerApplication'
  _globals['_CONSUMERAPPLICATION']._serialized_start=102
  _globals['_CONSUMERAPPLICATION']._serialized_end=5808
  _globals['_CONSUMERAPPLICATION_PAYLOAD']._serialized_start=266
  _globals['_CONSUMERAPPLICATION_PAYLOAD']._serialized_end=599
  _globals['_CONSUMERAPPLICATION_SUBPROTOCOLPAYLOAD']._serialized_start=601
  _globals['_CONSUMERAPPLICATION_SUBPROTOCOLPAYLOAD']._serialized_end=673
  _globals['_CONSUMERAPPLICATION_METADATA']._serialized_start=676
  _globals['_CONSUMERAPPLICATION_METADATA']._serialized_end=833
  _globals['_CONSUMERAPPLICATION_METADATA_SPECIALTEXTSIZE']._serialized_start=782
  _globals['_CONSUMERAPPLICATION_METADATA_SPECIALTEXTSIZE']._serialized_end=833
  _globals['_CONSUMERAPPLICATION_SIGNAL']._serialized_start=835
  _globals['_CONSUMERAPPLICATION_SIGNAL']._serialized_end=843
  _globals['_CONSUMERAPPLICATION_APPLICATIONDATA']._serialized_start=845
  _globals['_CONSUMERAPPLICATION_APPLICATIONDATA']._serialized_end=960
  _globals['_CONSUMERAPPLICATION_CONTENT']._serialized_start=963
  _globals['_CONSUMERAPPLICATION_CONTENT']._serialized_end=2525
  _globals['_CONSUMERAPPLICATION_EDITMESSAGE']._serialized_start=2527
  _globals['_CONSUMERAPPLICATION_EDITMESSAGE']._serialized_end=2636
  _globals['_CONSUMERAPPLICATION_POLLADDOPTIONMESSAGE']._serialized_start=2638
  _globals['_CONSUMERAPPLICATION_POLLADDOPTIONMESSAGE']._serialized_end=2731
  _globals['_CONSUMERAPPLICATION_POLLVOTEMESSAGE']._serialized_start=2733
  _globals['_CONSUMERAPPLICATION_POLLVOTEMESSAGE']._serialized_end=2802
  _globals['_CONSUMERAPPLICATION_POLLENCVALUE']._serialized_start=2804
  _globals['_CONSUMERAPPLICATION_POLLENCVALUE']._serialized_end=2853
  _globals['_CONSUMERAPPLICATION_POLLUPDATEMESSAGE']._serialized_start=2856
  _globals['_CONSUMERAPPLICATION_POLLUPDATEMESSAGE']._serialized_end=3076
  _globals['_CONSUMERAPPLICATION_POLLCREATIONMESSAGE']._serialized_start=3079
  _globals['_CONSUMERAPPLICATION_POLLCREATIONMESSAGE']._serialized_end=3230
  _globals['_CONSUMERAPPLICATION_OPTION']._serialized_start=3232
  _globals['_CONSUMERAPPLICATION_OPTION']._serialized_end=3260
  _globals['_CONSUMERAPPLICATION_REACTIONMESSAGE']._serialized_start=3263
  _globals['_CONSUMERAPPLICATION_REACTIONMESSAGE']._serialized_end=3431
  _globals['_CONSUMERAPPLICATION_REVOKEMESSAGE']._serialized_start=3433
  _globals['_CONSUMERAPPLICATION_REVOKEMESSAGE']._serialized_end=3483
  _globals['_CONSUMERAPPLICATION_VIEWONCEMESSAGE']._serialized_start=3486
  _globals['_CONSUMERAPPLICATION_VIEWONCEMESSAGE']._serialized_end=3684
  _globals['_CONSUMERAPPLICATION_GROUPINVITEMESSAGE']._serialized_start=3687
  _globals['_CONSUMERAPPLICATION_GROUPINVITEMESSAGE']._serialized_end=3853
  _globals['_CONSUMERAPPLICATION_LIVELOCATIONMESSAGE']._serialized_start=3856
  _globals['_CONSUMERAPPLICATION_LIVELOCATIONMESSAGE']._serialized_end=4121
  _globals['_CONSUMERAPPLICATION_CONTACTSARRAYMESSAGE']._serialized_start=4123
  _globals['_CONSUMERAPPLICATION_CONTACTSARRAYMESSAGE']._serialized_end=4243
  _globals['_CONSUMERAPPLICATION_CONTACTMESSAGE']._serialized_start=4245
  _globals['_CONSUMERAPPLICATION_CONTACTMESSAGE']._serialized_end=4301
  _globals['_CONSUMERAPPLICATION_STATUSTEXTMESAGE']._serialized_start=4304
  _globals['_CONSUMERAPPLICATION_STATUSTEXTMESAGE']._serialized_end=4646
  _globals['_CONSUMERAPPLICATION_STATUSTEXTMESAGE_FONTTYPE']._serialized_start=4528
  _globals['_CONSUMERAPPLICATION_STATUSTEXTMESAGE_FONTTYPE']._serialized_end=4646
  _globals['_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE']._serialized_start=4649
  _globals['_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE']._serialized_end=4961
  _globals['_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE_PREVIEWTYPE']._serialized_start=4927
  _globals['_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE_PREVIEWTYPE']._serialized_end=4961
  _globals['_CONSUMERAPPLICATION_LOCATIONMESSAGE']._serialized_start=4963
  _globals['_CONSUMERAPPLICATION_LOCATIONMESSAGE']._serialized_end=5068
  _globals['_CONSUMERAPPLICATION_STICKERMESSAGE']._serialized_start=5070
  _globals['_CONSUMERAPPLICATION_STICKERMESSAGE']._serialized_end=5126
  _globals['_CONSUMERAPPLICATION_DOCUMENTMESSAGE']._serialized_start=5128
  _globals['_CONSUMERAPPLICATION_DOCUMENTMESSAGE']._serialized_end=5204
  _globals['_CONSUMERAPPLICATION_VIDEOMESSAGE']._serialized_start=5206
  _globals['_CONSUMERAPPLICATION_VIDEOMESSAGE']._serialized_end=5298
  _globals['_CONSUMERAPPLICATION_AUDIOMESSAGE']._serialized_start=5300
  _globals['_CONSUMERAPPLICATION_AUDIOMESSAGE']._serialized_end=5365
  _globals['_CONSUMERAPPLICATION_IMAGEMESSAGE']._serialized_start=5367
  _globals['_CONSUMERAPPLICATION_IMAGEMESSAGE']._serialized_end=5459
  _globals['_CONSUMERAPPLICATION_INTERACTIVEANNOTATION']._serialized_start=5462
  _globals['_CONSUMERAPPLICATION_INTERACTIVEANNOTATION']._serialized_end=5643
  _globals['_CONSUMERAPPLICATION_POINT']._serialized_start=5645
  _globals['_CONSUMERAPPLICATION_POINT']._serialized_end=5674
  _globals['_CONSUMERAPPLICATION_LOCATION']._serialized_start=5676
  _globals['_CONSUMERAPPLICATION_LOCATION']._serialized_end=5751
  _globals['_CONSUMERAPPLICATION_MEDIAPAYLOAD']._serialized_start=5753
  _globals['_CONSUMERAPPLICATION_MEDIAPAYLOAD']._serialized_end=5808
# @@protoc_insertion_point(module_scope)
